@@ -29,7 +29,6 @@
 #include "allocate.h"
 #include "add_server.h"
 #include "show_info.h"
-#include "system_defines.h"
 #include "populate_servers.h"
 #include "populate_conf_tab.h"
 
@@ -64,27 +63,21 @@ void add_server(struct w *widgets)
     strcat(server_config, "TimeoutLogin 300\n");
     strcat(server_config, "TimeoutNoTransfer 120\n");
     strcat(server_config, "TimeoutIdle 120\n");
-
     strcat(server_config, "User ");
     strcat(server_config, SERVER_USER);
     strcat(server_config, "\n");
-
     strcat(server_config, "Group ");
     strcat(server_config, SERVER_GROUP);
     strcat(server_config, "\n");
-
     strcat(server_config, "DirFakeUser on ");
     strcat(server_config, SERVER_USER);
     strcat(server_config, "\n");
-
     strcat(server_config, "DirFakeGroup on ");
     strcat(server_config, SERVER_GROUP);
     strcat(server_config, "\n");
-
     strcat(server_config, "DefaultTransferMode binary\n");
-    strcat(server_config, "AllowForeignAddress on\n");
+    strcat(server_config, "AllowForeignAddress off\n");
     strcat(server_config, "DeleteAbortedStores off\n");
-
     strcat(server_config, "AllowRetrieveRestart on\n");
     strcat(server_config, "AllowStoreRestart on\n");
     strcat(server_config, "TransferRate RETR 30\n");
@@ -92,24 +85,36 @@ void add_server(struct w *widgets)
     strcat(server_config, "TransferRate STOU 50\n");
     strcat(server_config, "TransferRate APPE 50\n");
 
+    /* TLS Module settings, off by default */
     strcat(server_config, "<IfModule mod_tls.c>\n");
     strcat(server_config, "TLSEngine off\n");
     strcat(server_config, "TLSRequired off\n");
     strcat(server_config, "TLSVerifyClient off\n");
-
     strcat(server_config, "TLSLog ");
     strcat(server_config, GP_VARDIR);
     strcat(server_config, "/log/proftpd_tls.log\n");
-
     strcat(server_config, "TLSRSACertificateFile ");
     strcat(server_config, GP_APPCONFDIR);
-    strcat(server_config, "/gproftpd/gproftpd.pem\n");
-
+    strcat(server_config, "/gproftpd.pem\n");
     strcat(server_config, "</IfModule>\n");
+
+    /* RATIO Module settings, off by default */ 
+    strcat(server_config, "<IfModule mod_ratio.c>\n");
+    strcat(server_config, "Ratios off\n");
+    strcat(server_config, "SaveRatios off\n");
+    strcat(server_config, "RatioFile \"/restricted/proftpd_ratios\"\n");
+    strcat(server_config, "RatioTempFile \"/restricted/proftpd_ratios_temp\"\n");
+    strcat(server_config, "CwdRatioMsg \"Please upload first!\"\n");
+    strcat(server_config, "FileRatioErrMsg \"FileRatio limit exceeded, upload something first...\"\n");
+    strcat(server_config, "ByteRatioErrMsg \"ByteRatio limit exceeded, upload something first...\"\n");
+    strcat(server_config, "LeechRatioMsg \"Your ratio is unlimited.\"\n");
+    strcat(server_config, "</IfModule>\n");
+
     strcat(server_config, "<Limit LOGIN>\n");
     strcat(server_config, "  DenyAll\n");
     strcat(server_config, "</Limit>\n");
     strcat(server_config, "</VirtualHost>\n");
+
     fputs("\n", fp);
     fputs(server_config, fp);
     fputs("\n", fp);
