@@ -19,8 +19,6 @@
  */
 
 
-
-
 #include "../config.h"
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -33,44 +31,59 @@
 #include "show_info.h"
 #include "add_user.h"
 #include "functions.h"
+#include "dir_treeview_funcs.h"
 #include "system_defines.h"
-
 #include "populate_users.h"
 #include "populate_user_settings.h"
 #include "populate_conf_tab.h"
 #include "select_first_user.h"
 #include "reread_conf.h"
 
-
 #ifdef USE_DARWIN
 #include "osx_functions.h"
 #endif
 
-
 extern char global_server_address[1024];
 extern char global_server_port[1024];
 extern char global_server_type[1024];
 
+extern int use_ratio;
+extern int use_quota;
+
+extern long num_rows;
+extern int row_pos;
+
+/* Used globally with dir_treeview_funcs.c */
+char *user_profile;
+
+/* Set in dir_treeview_funcs.c */
+extern gchar *homedir;
+
+/* Declared in gproftpd.c and set in treeview_dir_funcs */
+extern int global_dir_error;
+
+/* Temporary, for option deprecations in proftpd */
+extern char global_version[1024];
+
 
 
 void add_user(struct w *widgets)
 {
     /* Adds a new user to the selected server */
     FILE *fp;
-    long conf_size;
+    long conf_size = 0;
+    long profile_size = 0;
     char *old_buffer, *new_buffer;
-    char *user_settings, *user_check, *address_buffer, *port_buffer;
-    char *home_dir;
+    char *user_check, *address_buffer, *port_buffer;
     int length=0, limit_access=0, user_added=0;
     int found_server=0, standard_server=0;
-    char fixdir[16384]="";
     gchar *utf8=NULL;
-    gchar *info, *cmd;
+    gchar *info, *cmd, *restricted_dir=NULL;
+    G_CONST_RETURN gchar *br=NULL, *brc=NULL, *fr=NULL, *frc=NULL;
 
     G_CONST_RETURN gchar *username;
     G_CONST_RETURN gchar *password;
     G_CONST_RETURN gchar *group;
-    G_CONST_RETURN gchar *homedir;
     G_CONST_RETURN gchar *comment;
     G_CONST_RETURN gchar *shell;
 
@@ -78,7 +91,6 @@ void add_user(struct w *widgets)
     password  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[1]));
     group     = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[2]));
     comment   = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[3]));
-    homedir   = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[4]));
     /* Shell is a gtk_combo_box_entry_new_text */
     shell     = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(widgets->user_set_combo[0])->child));
 
@@ -88,6 +100,16 @@ void add_user(struct w *widgets)
      * This is done so that no user gets sshd/etc access unless the admin wants to.
      */
 
+    /* Ratios */
+    if( use_ratio )
+    {
+        br  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[1]));
+        brc = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[2]));
+        fr  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[3]));
+        frc = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[4]));
+    }
+
+
     /* If the username field is empty inform that this cant be done. */
     length = strlen(username);
     if( length == 0 ) 
@@ -153,16 +175,6 @@ void add_user(struct w *widgets)
     	return;
     }
 
-    /* If the directory field has 0 chars we inform that this cant be done */
-    length = strlen(homedir);
-    if( length < 8 )  /* /home/b /var/abc */
-    {
-	info = g_strdup_printf(_("Failed adding user: %s\nThe specified home directory is too short.\n"), username);
-	show_info(info);
-	g_free(info);
-    	return;
-    }
-
     /* A comment is required */
     length = strlen(comment);
     if( length == 0 ) 
@@ -189,9 +201,7 @@ void add_user(struct w *widgets)
     old_buffer = allocate(conf_size);
     user_check = allocate(4096);
 
-    strcpy(user_check, "User ");
-    strcat(user_check, username);
-    strcat(user_check, "\n"); /* Similar user confusion */
+    snprintf(user_check, 4000, "User %s\n", username);
 
     address_buffer = allocate(8192+15);
     port_buffer = allocate(8192+3);               
@@ -246,7 +256,6 @@ void add_user(struct w *widgets)
     }
 
 
-
     /* We have begun at the top for the standard server 
      * or scrolled to the selected vhost. */
     
@@ -262,8 +271,8 @@ void add_user(struct w *widgets)
  	    show_info(info);
 	    g_free(info);
 
-	    free(user_check);
 	    free(old_buffer);
+	    free(user_check);
 	    free(address_buffer);
 	    free(port_buffer);
 	    fclose(fp);
@@ -406,46 +415,144 @@ void add_user(struct w *widgets)
     }
 
 
+    /* Setup the users profile and create its directories */
 
-    /* Setup the user profile and directories */
+    /* Set the homedir globally from the first row in the treeview using row_pos=0 */
+    num_rows = 0;/* Set global num_rows */
+    gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->directory_store), (GtkTreeModelForeachFunc) num_rows_func, widgets);
+
+    if( num_rows < 1 )
+    {
+	info = g_strdup_printf(_("Missing ftp home directory. Scroll down and add one first.\n"));
+	show_info(info);
+	g_free(info);
+	return;
+    }
+            
+    /* (Global) Statics + entries + (number of rows * dirlen + APPE STOR STOU etc) */
+    profile_size = 16384 + 1400   + (num_rows * 16384);
+    /* Allocate the user profile */
+    user_profile = allocate(profile_size+1);
+
+    /* Set the users home dir and its access settings globally */
+    row_pos = 0; /* Only get the home directory */
+    gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->directory_store), (GtkTreeModelForeachFunc) dirs_foreach, widgets);
+
+    /* Bad directory name or no directory at all */
+    if( global_dir_error )
+    {
+	/* Info is shown in the foreach function */
+	global_dir_error = 0;
+
+	free(user_profile);
+
+	if( homedir!=NULL )
+	  g_free(homedir);
+
+	return;
+    }
+    
+
+    /* If ratios is used it needs a restricted toplevel directory and
+       a block all .ftpaccess file in this toplevel directory */
+    if( use_ratio )
+    {
+	/* Make the restricted directory under each users chroot directory */
+	restricted_dir = g_strdup_printf("%s/%s", homedir, "restricted");
+	make_dir_chmod((gchar *)restricted_dir, "0777"); /* Must be like this */
+
+	/* Add a block all .ftpaccess file to this directory */
+	cmd = g_strdup_printf("echo \"DenyAll\n\" > %s/.ftpaccess", restricted_dir);
+	if( ! run_command(cmd) )    
+	{
+	    printf("Error creating .ftpaccess file here: %s/.ftpaccess\n", restricted_dir);
+	    /* Fixme, popup */
+	}
+	g_free(cmd);
+
+	/* Add the ratio files */
+	cmd = g_strdup_printf("touch %s/proftpd_ratios %s/proftpd_ratios_temp", restricted_dir, restricted_dir);
+	if( ! run_command(cmd) )    
+	{
+	    printf("Error creating the ratio files here: %s\n", restricted_dir);
+	    /* Fixme, popup */
+	}    
+	g_free(cmd);
+    
+	/* Chmod a+rw on the ratio files (must be a+rw) */
+	cmd = g_strdup_printf("chmod a+rw %s/proftpd_ratios %s/proftpd_ratios_temp", restricted_dir, restricted_dir);
+	if( ! run_command(cmd) )    
+	{
+	    printf("Error chmodding the ratio files here: %s\n", restricted_dir);
+	    /* Fixme, popup */
+	}    
+	g_free(cmd);
+
+	/* Chown ratio files to SERVERUSER:SERVERGROUP */
+	cmd = g_strdup_printf("chown %s:%s %s/proftpd_ratios %s/proftpd_ratios_temp", SERVER_USER, SERVER_GROUP, restricted_dir, restricted_dir);
+	if( ! run_command(cmd) )    
+	{
+	    printf("Error chmodding the ratio files here: %s\n", restricted_dir);
+	    /* Fixme, popup */
+	}    
+	g_free(cmd);
+
+	g_free(restricted_dir);
+    }    
 
 
-    /* Check that slashes in directory path combinations have slashes in the right place */
-    home_dir = allocate(4096);
-    strcpy(home_dir, homedir);
-    fix_path(home_dir);
-
-    /* Make the users ftp directory in /var/.. and chmod it to 0755 */
-    strcpy(fixdir, home_dir);
-    make_dir_chmod((gchar *)home_dir, "0755");
 
     /* The users configuration profile */
-    user_settings = allocate(16384);
-    strcpy(user_settings, "\n<Anonymous ");
-    strcat(user_settings, home_dir);
-    strcat(user_settings, ">\n");
-    strcat(user_settings, "User ");
-    strcat(user_settings, username);
-    strcat(user_settings, "\nGroup ");
-    strcat(user_settings, group);
-    strcat(user_settings, "\n");
-    strcat(user_settings, "AnonRequirePassword on\n");
-    strcat(user_settings, "MaxClients 5 \"The server is full, hosting %m users\"\n");
-    strcat(user_settings, "DisplayLogin welcome.msg\n");
-    strcat(user_settings, "DisplayFirstChdir .msg\n");
-    strcat(user_settings, "<Limit LOGIN>\n");
-    strcat(user_settings, " Allow from all\n");
-    strcat(user_settings, " Deny from all\n");
-    strcat(user_settings, "</Limit>\n");
-    strcat(user_settings, "AllowOverwrite off\n");
-    strcat(user_settings, "<Limit RETR LIST NLST MDTM SIZE STAT CWD XCWD PWD XPWD CDUP XCUP>\n");
-    strcat(user_settings, " AllowAll\n");
-    strcat(user_settings, "</Limit>\n");
-    strcat(user_settings, "<Limit DELE APPE STOR STOU SITE_CHMOD SITE_CHGRP RNFR RNTO MKD XMKD RMD XRMD>\n");
-    strcat(user_settings, " DenyAll\n");
-    strcat(user_settings, "</Limit>\n");
-    strcat(user_settings, "</Anonymous>\n");
-    free(home_dir);
+    strcpy(user_profile, "\n<Anonymous ");
+    strcat(user_profile, homedir);
+    strcat(user_profile, ">\n");
+    strcat(user_profile, "User ");
+    strcat(user_profile, username);
+    strcat(user_profile, "\nGroup ");
+    strcat(user_profile, group);
+    strcat(user_profile, "\n");
+    strcat(user_profile, "AnonRequirePassword on\n");
+    strcat(user_profile, "MaxClients 5 \"The server is full, hosting %m users\"\n");
+    strcat(user_profile, "DisplayLogin welcome.msg\n");
+
+    /* Fix for a changed directive, sorry Fedora backported... */
+//    if( strstr(global_version, "1.2.") || strstr(global_version, "1.3.0") )
+//      strcat(user_profile, "DisplayFirstChdir .msg\n");
+//    else
+//      strcat(user_profile, "DisplayChdir .msg\n");
+      
+    /* Ratio Module (reversed br/fr order in the gui) */
+    if( use_ratio )
+    {
+        strcat(user_profile, "UserRatio ");
+        strcat(user_profile, username);
+        strcat(user_profile, " ");
+        strcat(user_profile, fr);
+        strcat(user_profile, " ");
+        strcat(user_profile, frc);
+        strcat(user_profile, " ");
+        strcat(user_profile, br);
+        strcat(user_profile, " ");
+	strcat(user_profile, brc);
+        strcat(user_profile, "\n");
+    }
+
+    strcat(user_profile, "<Limit LOGIN>\n");
+    strcat(user_profile, " Allow from all\n");
+    strcat(user_profile, " Deny from all\n");
+    strcat(user_profile, "</Limit>\n");
+    strcat(user_profile, "AllowOverwrite off\n");
+
+    append_limit_cmds();
+
+    row_pos = 1; /* Append and create the rest of the directories */
+    gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->directory_store), (GtkTreeModelForeachFunc) dirs_foreach, widgets);
+
+    strcat(user_profile, "</Anonymous>\n");
+
+    if( homedir!=NULL )
+      g_free(homedir);
+
 
     /* Add the new user settings and AllowUser to the correct server */
     found_server = 0;
@@ -459,7 +566,7 @@ void add_user(struct w *widgets)
     {
 	free(address_buffer);
 	free(port_buffer);
-	free(user_settings);
+	free(user_profile);
     	return;
     }
     fseek(fp, 0, SEEK_END);
@@ -519,7 +626,7 @@ void add_user(struct w *widgets)
 	       {
 		    /* Only add it once */
 		    limit_access = 2;
-		    strcat(new_buffer, user_settings);
+		    strcat(new_buffer, user_profile);
 	       }
 	    }
 	}
@@ -529,15 +636,14 @@ void add_user(struct w *widgets)
 	{
 	   /* Only add it once */
 	   limit_access = 2;
-	   strcat(new_buffer, user_settings);
+	   strcat(new_buffer, user_profile);
 	}
     }
     fclose(fp);
     free(old_buffer);      
     free(address_buffer);
     free(port_buffer);
-    free(user_settings);
-
+    free(user_profile);
 
 
     /* Password the user if it didnt exist before */
