@@ -41,22 +41,24 @@ extern char global_server_address[1024];
 extern char global_server_port[1024];
 extern char global_server_type[1024];
 
-extern int use_tls;
-
 extern int activated;
 
+extern int use_tls;
+extern int use_ratio;
+extern int use_quota;
+
+
 
 void apply_server_settings(struct w *widgets)
 {
     /* Change the selected servers configuration. */
     FILE *fp;
     long conf_size;
-    gint active_index;
-    gchar *address_line, *port_line;
     int address_match = 0, port_match = 0;
-    gchar *info;
-        
     int configuration_changed = 0;
+    gint active_index;
+    gchar *address_line, *port_line, *info;
+        
     char *change_srv_ident;
     char *old_buffer, *config, *temp_server, *conf_line, *address_buffer, *port_buffer;
     gchar *old_server_ident;
@@ -120,8 +122,8 @@ void apply_server_settings(struct w *widgets)
     upload_bandwidth = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_spinbutton[9]));
     download_bandwidth = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_spinbutton[10]));
 
-    /* Save the old server ident so we know if we should 
-     * repopulate the server treeview */
+
+    /* Save the old server ident so we know if we should repopulate the server treeview */
     old_server_ident = g_strdup_printf("%s", server_ident);
 
 
@@ -135,9 +137,6 @@ void apply_server_settings(struct w *widgets)
 	/* Should we change the certificate entries as well ? */
     }
 
-
-
-
     address_buffer = allocate(8192+15);
     port_buffer = allocate(8192+3);               
 
@@ -147,34 +146,41 @@ void apply_server_settings(struct w *widgets)
     sprintf(port_buffer, "Port %s\n", global_server_port);
 
 
-    if( strlen(address_buffer) == 0 && strstr((char *)global_server_type, "Virtualhost") ) 
+// use global_server_address
+    if( strlen(address_buffer) == 0 
+    && strstr((char *)global_server_type, "Virtualhost") ) 
     {
 	info = g_strdup_printf(_("Refusing to change a server without a specified name.\n"));
 	show_info(info);
 	g_free(info);
+
 	free(address_buffer);
 	free(port_buffer);
         g_free(old_server_ident);
         return;
     }
 
+    // use < 8 or global_server_port
     if( strlen(port_buffer) == 0 ) 
     {
 	info = g_strdup_printf(_("Refusing to change a server without a specified port.\n"));
 	show_info(info);
 	g_free(info);
+
 	free(address_buffer);
 	free(port_buffer);
         g_free(old_server_ident);
         return;
     }
 
+
     /* Change the configuration for the selected server */
     if((fp=fopen(PROFTPD_CONF, "r"))==NULL)
     {
 	info = g_strdup_printf(_("Cant open proftpd.conf here: \n%s\n"), PROFTPD_CONF);
 	show_info(info);
 	g_free(info);
+
 	free(address_buffer);
 	free(port_buffer);
         g_free(old_server_ident);
@@ -184,6 +190,7 @@ void apply_server_settings(struct w *widgets)
     conf_size = ftell(fp);
     rewind(fp);
 
+
     config = allocate(conf_size+16384); /* Additional bytes */
     old_buffer = allocate(conf_size);
     temp_server = allocate(conf_size);
@@ -191,28 +198,31 @@ void apply_server_settings(struct w *widgets)
     change_srv_ident = allocate(8192);
 
 
+
 /* ------------- Change the standard server ----------- */
 
     if( strstr("Default server", (char *)global_server_type) )
     {
-	configuration_changed=1;
+	configuration_changed = 1;
 
 	if( conf_size > 1 )
 	while(fgets(old_buffer, conf_size, fp)!=NULL)
 	{
-	    if( strlen(old_buffer) > 4000 )
+	    if( strlen(old_buffer) > 4000 ) // 8000...
 	    {
 		info = g_strdup_printf(_("A line with over 8000 chars is not valid in: %s\n"), PROFTPD_CONF);
 		show_info(info);
 		g_free(info);
-    		free(address_buffer);
-		free(port_buffer);
-		free(old_buffer);
+
 		free(config);
+		free(old_buffer);
 		free(temp_server);
 		free(conf_line);
 		free(change_srv_ident);
+    		free(address_buffer);
+		free(port_buffer);
                 g_free(old_server_ident);
+
 		fclose(fp);
 		return;
 	    }
@@ -258,20 +268,6 @@ void apply_server_settings(struct w *widgets)
 	        strcat(config, conf_line);
 	    }
 	    else
-
-/* Deprecated in proftpd 1.3.0
-		if( strstr(old_buffer, "SocketBindTight") )
-		{
-		    if( combo_selection(combo18) == 0 )
-    		      sprintf(conf_line, "SocketBindTight on\n");
-		    else
-    		      sprintf(conf_line, "SocketBindTight off\n");
-
-    		    strcat(config, conf_line);
-
-		}
-*/
-
 	    if( strstr(old_buffer, "ServerAdmin") )
 	    {
     	        sprintf(conf_line, "ServerAdmin %s\n", admin_email);
@@ -573,31 +569,88 @@ void apply_server_settings(struct w *widgets)
     	        sprintf(conf_line, "TLSRSACertificateFile %s\n", tls_certfile);
     	        strcat(config, conf_line);
 	    }   
+	    else
+	    
+	    /* If using Ratios */
+    	    if( use_ratio && strstr(old_buffer, "Ratios ") && ! strstr(old_buffer, "ave") ) /* Not SaveRatios */
+	    {
+		active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[16]));
+		if( active_index == 0 )
+    		  sprintf(conf_line, "Ratios on\n");
+		else
+    		  sprintf(conf_line, "Ratios off\n");
+
+    	    	strcat(config, conf_line);
+	    }
+	    else	    
+    	    if( use_ratio && strstr(old_buffer, "SaveRatios ") )
+	    {
+		active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[17]));
+		if( active_index == 0 )
+    		  sprintf(conf_line, "SaveRatios on\n");
+		else
+    		  sprintf(conf_line, "SaveRatios off\n");
+
+    	    	strcat(config, conf_line);
+	    }
 	    else
 	      strcat(config, old_buffer); /* Gather all other values */
 	}
+
     	free(old_buffer);
     	free(address_buffer);
     	free(port_buffer);
     	free(temp_server);
-    	free(conf_line);
-    	free(change_srv_ident);
+	free(conf_line);
+   	free(change_srv_ident);
     	fclose(fp);
+
+	/* Write the new config if any changes where made */
+	if( ! configuration_changed )
+	{
+	   g_free(old_server_ident);
+	   free(config);
+    	   return;
+	}
+
+	/* Write the new conf */
+	if((fp=fopen(PROFTPD_CONF, "w+"))==NULL)
+	{
+            g_free(old_server_ident);
+	    free(config);
+    	    return;
+	}
+	fputs(config, fp);
+	fclose(fp);
+	free(config);
+
+	/* The server address, ident or port hasnt changed, dont populate server tab */
+	if( ! strcmp(global_server_address, server_name) 
+	&&  ! strcmp(old_server_ident, server_ident)
+	&&  ! strcmp(global_server_port, server_port)  )
+	{}
+	else
+        {
+	    /* Populate the server treeview */
+	    populate_servers(widgets);
+	    /* Select the first server and set global server values */    
+	    select_first_server(widgets);
+	}
+
+	g_free(old_server_ident);
+	/* Populate the server settings */    
+	populate_server_settings(widgets);
+	populate_conf_tab(widgets);
+	/* Update the server */
+	reread_conf(widgets);
+
+	return;
     }
 /* ----------------- End of default server changes ------------------ */
 
 
 
 
-
-
-
-
-
-
-
-
-
 /* ------------ Change a virtualhost --------------- */
     if( strstr("Virtualhost", (char *)global_server_type) )
     {
@@ -646,23 +699,33 @@ void apply_server_settings(struct w *widgets)
 	      strcat(config, old_buffer);
 	}
 
-	g_free(address_line); g_free(port_line);
 
+	if( address_line !=NULL )
+	  g_free(address_line);
+	
+	if( port_line !=NULL )
+	  g_free(port_line);
 
 
 	/* Couldnt find the server */
 	if( ! address_match || ! port_match )
 	{
-	    printf("The virtualhost was not found, no changes where made\n");
-	    free(old_buffer);
-	    free(config);
-	    free(address_buffer);
-	    free(port_buffer);
-	    free(temp_server);
-	    free(conf_line);
-	    free(change_srv_ident);
-            g_free(old_server_ident);
+	    // Show info
+	    printf("The virtualhost was not found, no changes where made.\n");
+
 	    fclose(fp);
+
+//	    free(old_buffer);
+//	    free(address_buffer);
+//	    free(temp_server);
+//	    free(port_buffer);
+	    free(change_srv_ident);
+//new	    free(conf_line);
+	    free(config);
+
+            g_free(old_server_ident);
+
+	    printf("Broken...\n");
 	    return;
 	}
 
@@ -681,7 +744,7 @@ void apply_server_settings(struct w *widgets)
 	    {
 		/* This server will dissapear if it has no ending */
 
-		configuration_changed=1;
+		configuration_changed = 1;
 
 		/* Add the end of this server */
 	        strcat(config, old_buffer);
@@ -1018,6 +1081,30 @@ void apply_server_settings(struct w *widgets)
     	        sprintf(conf_line, "TLSRSACertificateFile %s\n", tls_certfile);
     	        strcat(config, conf_line);
 	    }   
+	    else
+	    
+	    /* If using Ratios */
+    	    if( use_ratio && strstr(old_buffer, "Ratios ") && ! strstr(old_buffer, "ave") ) /* Not SaveRatios */
+	    {
+		active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[16]));
+		if( active_index == 0 )
+    		  sprintf(conf_line, "Ratios on\n");
+		else
+    		  sprintf(conf_line, "Ratios off\n");
+
+    	    	strcat(config, conf_line);
+	    }
+	    else	    
+    	    if( use_ratio && strstr(old_buffer, "SaveRatios ") )
+	    {
+		active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[17]));
+		if( active_index == 0 )
+    		  sprintf(conf_line, "SaveRatios on\n");
+		else
+    		  sprintf(conf_line, "SaveRatios off\n");
+
+    	    	strcat(config, conf_line);
+	    }
 	    else
 	      strcat(config, old_buffer); /* Gather all other values */
 	}
@@ -1028,13 +1115,16 @@ void apply_server_settings(struct w *widgets)
 	free(change_srv_ident);
 	free(conf_line);
         fclose(fp);
-    }   /* If it was a vhost */
 
 
+	/* Write the new config if any changes where made */
+	if( ! configuration_changed )
+	{
+	   g_free(old_server_ident);
+	   free(config);
+    	   return;
+	}
 
-    /* Write the new config if any changes where made */
-    if( configuration_changed )
-    {
 	/* Make a space left check here */
 	if((fp=fopen(PROFTPD_CONF, "w+"))==NULL)
 	{
@@ -1045,37 +1135,25 @@ void apply_server_settings(struct w *widgets)
 	fputs(config, fp);
 	fclose(fp);
 	free(config);
-    }
-    else
-      {
-	   g_free(old_server_ident);
-	   free(config);
-    	   return;
-      }
 
+	/* The server address, ident or port hasnt changed, dont populate_servers */
+	if( ! strcmp(global_server_address, server_name) 
+	&&  ! strcmp(old_server_ident, server_ident)
+	&&  ! strcmp(global_server_port, server_port)  )
+	{  }
+	else
+	{
+	    /* Populate the server treeview */
+	    populate_servers(widgets);
+	    /* Select the first server and set global server values */    
+	    select_first_server(widgets);
+	}
+	g_free(old_server_ident);
+	/* Populate the server settings */    
+	populate_server_settings(widgets);
+	populate_conf_tab(widgets);
+	/* Update the server */
+	reread_conf(widgets);
 
-    /* The server address, ident or port hasnt changed, dont populate_servers */
-    if( ! strcmp(global_server_address, server_name) 
-    &&  ! strcmp(old_server_ident, server_ident)
-    &&  ! strcmp(global_server_port, server_port)    )
-    {
-    }
-    else
-      {
-	 /* Populate the server treeview */
-	 populate_servers(widgets);
-
-	 /* Select the first server and set global server values */    
-	 select_first_server(widgets);
-      }    
-
-    g_free(old_server_ident);
-
-    /* Populate the server settings */    
-    populate_server_settings(widgets);
-
-    populate_conf_tab(widgets);
-
-    /* Update the server */
-    reread_conf(widgets);
+    }   /* Vhost end */
 }
