@@ -19,8 +19,6 @@
  */
 
 
-
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,6 +34,7 @@
 #include "populate_user_settings.h"
 #include "populate_conf_tab.h"
 
+#include "dir_treeview_funcs.h"
 
 extern char global_server_address[1024];
 extern char global_server_port[1024];
@@ -43,352 +42,23 @@ extern char global_server_type[1024];
 
 extern int activated;
 
+extern int use_ratio;
+extern int use_quota;
+
+/* Temporary for option deprecations */
+extern char global_version[1024];
+
 /* The current directory beeing added and limited */
-gchar *dir;
+//gchar *dir; // ???
+extern gchar *homedir;
 
 /* The 18 checkbox values */
-gchar *dir_val[19];
+gchar *dir_val[19]; // ???
 
-char *user_profile;
-long num_rows = 0;
-int row_pos = 0;
-
-
-
-/* Get the number of rows in the treeview */
-gboolean num_rows_func(GtkTreeModel *model, GtkTreePath *path,
-		      GtkTreeIter *iter, struct w *widgets)
-{
-    num_rows++;
-    return FALSE;
-}
-
-
-
-void append_limit_cmds()
-{
-    int i, has_limit = 0;
-
-    /* Overwrite selected, add "Allowoverwrite on" before the directory limits */    
-    if( dir_val[6] )
-      strcat(user_profile, "AllowOverwrite on\n");
-    
-
-    strcat(user_profile, "<Limit");
-
-    /* ALLOW CMDs. Iter the 18 checkboxes */
-    for(i=1; i<19; i++)
-    {
-	/* The Box is checked, add to Limit allow */
-	if( i == 1 && dir_val[i])
-	{
-	    strcat(user_profile, " LIST NLST ");
-	    has_limit = 1;
-	}
-	
-	if( i == 2 && dir_val[i])
-	{
-	    strcat(user_profile, " STOR STOU ");
-	    has_limit = 1;
-	}
-
-	if( i == 3 && dir_val[i])
-	{
-	    strcat(user_profile, " APPE ");
-	    has_limit = 1;
-	}
-
-	if( i == 4 && dir_val[i])
-	{
-	    strcat(user_profile, " RETR ");
-	    has_limit = 1;
-	}
-
-	if( i == 5 && dir_val[i])
-	{
-	    strcat(user_profile, " RNFR RNTO ");
-	    has_limit = 1;
-	}
-
-	/* 6 is AllowOverwrite, its handled before this function is called */
-
-	if( i == 7 && dir_val[i])
-	{
-	    strcat(user_profile, " DELE ");
-	    has_limit = 1;
-	}
-
-	if( i == 8 && dir_val[i])
-	{
-	    strcat(user_profile, " MKD XMKD SITE_MKDIR ");
-	    has_limit = 1;
-	}
-
-	if( i == 9 && dir_val[i])
-	{
-	    strcat(user_profile, " RMD XRMD SITE_RMDIR ");
-	    has_limit = 1;
-	}
-
-	if( i == 10 && dir_val[i])
-	{
-	    strcat(user_profile, " SITE ");
-	    has_limit = 1;
-	}
-
-	if( i == 11 && dir_val[i])
-	{
-	    strcat(user_profile, " SITE_CHMOD ");
-	    has_limit = 1;
-	}
-
-	if( i == 12 && dir_val[i])
-	{
-	    strcat(user_profile, " SITE_CHGRP ");
-	    has_limit = 1;
-	}
-
-	/* Show modification dates "show time" */
-	if( i == 13 && dir_val[i])
-	{
-	    strcat(user_profile, " MTDM ");
-	    has_limit = 1;
-	}
-
-	/* Print working directory "show working directory" */
-	if( i == 14 && dir_val[i])
-	{
-	    strcat(user_profile, " PWD XPWD ");
-	    has_limit = 1;
-	}
-	
-	/* Show sizes */
-	if( i == 15 && dir_val[i])
-	{
-	    strcat(user_profile, " SIZE ");
-	    has_limit = 1;
-	}
-
-	/* Stat */
-	if( i == 16 && dir_val[i])
-	{
-	    strcat(user_profile, " STAT ");
-	    has_limit = 1;
-	}
-
-	/* Change working directory */
-	if( i == 17 && dir_val[i])
-	{
-	    strcat(user_profile, " CWD XCWD ");
-	    has_limit = 1;
-	}
-
-	/* CD up */
-	if( i == 18 && dir_val[i])
-	{
-	    strcat(user_profile, " CDUP XCUP ");
-	    has_limit = 1;
-	}
-    }
-
-    /* If theres no limit the server wont start or go off line */
-    if( ! has_limit )
-      strcat(user_profile, " NOTHING ");
-
-    strcat(user_profile, ">\n AllowAll\n</Limit>\n");
-
-
-
-    has_limit = 0;
-    strcat(user_profile, "<Limit");
-
-    /* DENY CMDs. Iter the 18 checkboxes */
-    for(i=1; i<19; i++)
-    {
-	/* The Box is not checked, add to Limit deny */
-	if( i == 1 && ! dir_val[i])
-	{
-	    strcat(user_profile, " LIST NLST ");
-	    has_limit = 1;
-	}
-
-	if( i == 2 && ! dir_val[i])
-	{
-	    strcat(user_profile, " STOR STOU ");
-	    has_limit = 1;
-	}
-
-	if( i == 3 && ! dir_val[i])
-	{
-	    strcat(user_profile, " APPE ");
-	    has_limit = 1;
-	}
-
-	if( i == 4 && ! dir_val[i])
-	{
-	    strcat(user_profile, " RETR ");
-	    has_limit = 1;
-	}
-
-	if( i == 5 && ! dir_val[i])
-	{
-	    strcat(user_profile, " RNFR RNTO ");
-	    has_limit = 1;
-	}
-
-	/* 6 is AllowOverwrite, its handled before this function is called */
-
-	if( i == 7 && ! dir_val[i])
-	{
-	    strcat(user_profile, " DELE ");
-	    has_limit = 1;
-	}
-
-	if( i == 8 && ! dir_val[i])
-	{
-	    strcat(user_profile, " MKD XMKD SITE_MKDIR ");
-	    has_limit = 1;
-	}
-
-	if( i == 9 && ! dir_val[i])
-	{
-	    strcat(user_profile, " RMD XRMD SITE_RMDIR ");
-	    has_limit = 1;
-	}
-
-	if( i == 10 && ! dir_val[i])
-	{
-	    strcat(user_profile, " SITE ");
-	    has_limit = 1;
-	}
-
-	if( i == 11 && ! dir_val[i])
-	{
-	    strcat(user_profile, " SITE_CHMOD ");
-	    has_limit = 1;
-	}
-
-	if( i == 12 && ! dir_val[i])
-	{
-	    strcat(user_profile, " SITE_CHGRP ");
-	    has_limit = 1;
-	}
-
-	/* Show modification dates "show time" */
-	if( i == 13 && ! dir_val[i])
-	{
-	    strcat(user_profile, " MTDM ");
-	    has_limit = 1;
-	}
-
-	/* Print working directory "show working directory" */
-	if( i == 14 && ! dir_val[i])
-	{
-	    strcat(user_profile, " PWD XPWD ");
-	    has_limit = 1;
-	}
-	
-	/* Show sizes */
-	if( i == 15 && ! dir_val[i])
-	{
-	    strcat(user_profile, " SIZE ");
-	    has_limit = 1;
-	}
-
-	/* Stat */
-	if( i == 16 && ! dir_val[i])
-	{
-	    strcat(user_profile, " STAT ");
-	    has_limit = 1;
-	}
-
-	/* Change working directory */
-	if( i == 17 && ! dir_val[i])
-	{
-	    strcat(user_profile, " CWD XCWD ");
-	    has_limit = 1;
-	}
-
-	/* CD up */
-	if( i == 18 && ! dir_val[i])
-	{
-	    strcat(user_profile, " CDUP XCUP ");
-	    has_limit = 1;
-	}
-    }
-
-    /* If theres no limit the server wont start or go off line */
-    if( ! has_limit )
-      strcat(user_profile, " NOTHING ");
-
-
-    strcat(user_profile, ">\n DenyAll\n</Limit>\n");
-}
-
-
-
-
-/* For each in the directory treeview */
-gboolean dirs_foreach(GtkTreeModel *model, GtkTreePath *path,
-		      GtkTreeIter *iter, struct w *widgets)
-{
-    int i;
-
-    /* Iter the 18 checkboxes on each row and save the values */
-    for(i=1; i<19; i++)
-    {
-	gtk_tree_model_get(model, iter, i, &dir_val[i], -1);
-    }
-
-    /* This is the first toplevel home directory */
-    if( row_pos == 0 )
-    {
-	gtk_tree_model_get(model, iter, 0, &dir, -1);    
-	row_pos++;
-
-	/* Need write: 1 2  4 5 6 7 8  10 */
-	if( dir_val[1] || dir_val[2] || dir_val[4] ||  dir_val[5]
-	||  dir_val[6] || dir_val[7] || dir_val[8] || dir_val[10] )
-          make_dir_chmod(dir, "0777"); /* Does mkdir -p, no need to check if it exists */
-	else
-	  make_dir_chmod(dir, "0777"); /* 0755 Noone else can write either... limited by the server. */
-
-	/* Return true so it stops here this time */
-	return TRUE;
-    }
-
-    row_pos++;
-
-    /* Ignore the first/home dir */
-    if( row_pos > 2 )
-    {
-	/* Add the rest of the users directories */
-	gtk_tree_model_get(model, iter, 0, &dir, -1);
-
-	/* Need write: 1 2  4 5 6 7 8  10 */
-	if( dir_val[1] || dir_val[2] || dir_val[4] ||  dir_val[5]
-	||  dir_val[6] || dir_val[7] || dir_val[8] || dir_val[10] )
-          make_dir_chmod(dir, "0777"); /* Does mkdir -p, no need to check if it exists */
-	else
-	  make_dir_chmod(dir, "0777"); /* 0755 Noone else can write either... limited by the server. */
-
-    
-	/* A directory, not the users home */
-	strcat(user_profile, "<Directory ");
-	strcat(user_profile, dir);
-	strcat(user_profile, ">\n");
-
-	append_limit_cmds();
-
-	strcat(user_profile, "</Directory>\n");
-
-	g_free(dir);
-    }
-    
-    /* Return false to keep foreach func going */
-    return FALSE;
-}						   
+char *user_profile; // ???
 
+extern long num_rows;
+extern int row_pos;
 
 
 /* Fixme mod: group, comment and shell */
@@ -413,6 +83,7 @@ void apply_user(struct w *widgets)
     G_CONST_RETURN gchar *password;
     G_CONST_RETURN gchar *login_from;
     G_CONST_RETURN gchar *max_logins;
+    G_CONST_RETURN gchar *br=NULL, *brc=NULL, *fr=NULL, *frc=NULL;
 
     /* Get the settings from the entries */
     username = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[0]));
@@ -422,6 +93,16 @@ void apply_user(struct w *widgets)
     login_from = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[5]));
     max_logins = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[0]));
 
+    /* Ratios */
+    if( use_ratio )
+    {
+	br  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[1]));
+	brc = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[2]));
+	fr  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[3]));
+	frc = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[4]));
+    }
+
+
     if( password!=NULL )
       password_length = strlen(password);
 
@@ -435,11 +116,19 @@ void apply_user(struct w *widgets)
     }
 
 
-
     /* Set global num_rows */
     num_rows = 0;
     gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->directory_store), (GtkTreeModelForeachFunc) num_rows_func, widgets);
 
+    /* There must be atleast one directory */
+    if( num_rows < 1 )
+    {
+	info = g_strdup_printf(_("Missing ftp home directory. Scroll down and add one first.\n"));
+	show_info(info);
+	g_free(info);
+	return;    
+    }
+
     /* (Global char) Statics + entries + number of rows (dirlen + APPE STOR STOU etc) */
     profile_size = 16384 + 1400 + (num_rows * 16384);
     /* Allocate the user profile */
@@ -453,10 +142,9 @@ void apply_user(struct w *widgets)
     /* Create the user profile... */
 
     /* Home directory */
-    snprintf(user_profile, 16384, "\n<Anonymous %s>\n", dir);
+    snprintf(user_profile, 16384, "\n<Anonymous %s>\n", homedir); // ERROR!!!
+
 
-    /* Free dir after foreach (itered once) */
-    g_free(dir);
 
 
     /* Username */    
@@ -475,7 +163,6 @@ void apply_user(struct w *widgets)
     else
       strcat(user_profile, "AnonRequirePassword on\n");
 
-    
     /* Maximum logins */
     strcat(user_profile, "MaxClients ");
     strcat(user_profile, max_logins);
@@ -485,7 +172,28 @@ void apply_user(struct w *widgets)
 
     /* Static Welcome and chdir msgs */
     strcat(user_profile, "DisplayLogin welcome.msg\n");
-    strcat(user_profile, "DisplayFirstChdir .msg\n");
+
+//  Fedora backported all but this!
+//    if( strstr(global_version, "1.2.") || strstr(global_version, "1.3.0") ) 
+//      strcat(user_profile, "DisplayFirstChdir .msg\n");
+//    else
+//      strcat(user_profile, "DisplayChdir .msg\n");
+
+    /* Ratio Module (reversed br/fr order in the gui) */
+    if( use_ratio )
+    {
+	strcat(user_profile, "UserRatio ");
+	strcat(user_profile, username);
+	strcat(user_profile, " ");
+	strcat(user_profile, fr);
+	strcat(user_profile, " ");
+	strcat(user_profile, frc);
+	strcat(user_profile, " ");
+	strcat(user_profile, br);
+	strcat(user_profile, " ");
+	strcat(user_profile, brc);
+	strcat(user_profile, "\n");
+    }
 
     /* Logins from, if nothing is specified we allow everything */
     if( login_from == NULL || strlen(login_from) < 3 )
@@ -519,6 +227,8 @@ void apply_user(struct w *widgets)
     /* Profile end */
     strcat(user_profile, "</Anonymous>\n");
 
+    if( homedir!=NULL )
+      g_free(homedir);
 
     /* We have the new profile, insert it where the old user was located in the selected server */
     UserUsername = g_strdup_printf("User %s\n", username);
