@@ -22,9 +22,15 @@
 #ifndef commands_H
 #	define commands_H
 
+extern struct w *widgets;
+
 int run_command(gchar *command);
 void run_command_show_err(gchar *command);
 int file_exists(char *infile);
 int using_tls(void);
+int using_ratio(void);
+int using_quota(void);
+void init_start(struct w *widgets);
+void init_stop(struct w *widgets);
 
 #endif
