@@ -31,6 +31,7 @@
 #include "gettext.h"
 #include "widgets.h"
 #include "allocate.h"
+#include "functions.h"
 #include "import_functions.h"
 #include "create_import_window.h"
 
@@ -46,9 +47,9 @@ void create_import_window(struct w *widgets)
     GtkTreeIter iter;
     GtkTreeSelection *selection;
     gchar *utf8=NULL;
-    GtkTreeViewColumn *user_col;
+    gchar *username, *groupname; //, *what, *val;
+    GtkTreeViewColumn *user_col, *group_col;
     GtkCellRenderer *import_cell_renderer;
-
     GtkWidget *import_vbox;
     GtkWidget *import_label0;
     GtkWidget *import_scrolledwindow;
@@ -58,8 +59,8 @@ void create_import_window(struct w *widgets)
     GtkWidget *import_hbox3;
     GtkWidget *import_label2;
     GtkWidget *import_hbox2;
-    GtkWidget *import_label3;
     GtkWidget *import_label4;
+    GtkWidget *spacer_label1;
     GtkWidget *import_hbuttonbox;
     GtkWidget *import_button;
     GtkWidget *alignment1;
@@ -83,7 +84,7 @@ void create_import_window(struct w *widgets)
     import_vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(widgets->import_window), import_vbox);
 
-    import_label0 = gtk_label_new(_("Import users to the currently selected server."));
+    import_label0 = gtk_label_new(_("Import users to the selected server."));
     gtk_box_pack_start(GTK_BOX(import_vbox), import_label0, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(import_label0), GTK_JUSTIFY_LEFT);
     gtk_misc_set_padding(GTK_MISC(import_label0), 0, 5);
@@ -96,7 +97,7 @@ void create_import_window(struct w *widgets)
     gtk_container_add(GTK_CONTAINER(import_scrolledwindow), widgets->import_treeview);
     gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(widgets->import_treeview), TRUE);
 
-    widgets->import_store = gtk_list_store_new(1, G_TYPE_STRING); //, G_TYPE_STRING);
+    widgets->import_store = gtk_list_store_new(2, G_TYPE_STRING , G_TYPE_STRING);
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->import_treeview), GTK_TREE_MODEL(widgets->import_store));
 
     /* Set the column labels in the treeview */
@@ -105,21 +106,25 @@ void create_import_window(struct w *widgets)
     user_col = gtk_tree_view_column_new_with_attributes(_("Username"), import_cell_renderer, "text", 0, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->import_treeview), GTK_TREE_VIEW_COLUMN(user_col));
 
+    group_col = gtk_tree_view_column_new_with_attributes(_("Groupname"), import_cell_renderer, "text", 0, NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->import_treeview), GTK_TREE_VIEW_COLUMN(group_col));
+
 
     /* Selection is multiple */
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(widgets->import_treeview));
     gtk_tree_selection_set_mode(GTK_TREE_SELECTION(selection), GTK_SELECTION_MULTIPLE);
 
+    spacer_label1 = gtk_label_new(" ");
+    gtk_box_pack_start(GTK_BOX(import_vbox), spacer_label1, FALSE, FALSE, 0);
 
-
-    label4 = gtk_label_new(_("All selected users will be imported with the following settings:"));
+    label4 = gtk_label_new(_("Selected users will be imported with the following settings:"));
     gtk_box_pack_start(GTK_BOX(import_vbox), label4, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(label4), GTK_JUSTIFY_LEFT);
 
     import_hbox1 = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(import_vbox), import_hbox1, FALSE, FALSE, 0);
 
-    import_label1 = gtk_label_new(_("The users will have this root directory:"));
+    import_label1 = gtk_label_new(_("FTP home directory:"));
     gtk_box_pack_start(GTK_BOX(import_hbox1), import_label1, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(import_label1), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment(GTK_MISC(import_label1), 0.02, 0.5);
@@ -132,32 +137,18 @@ void create_import_window(struct w *widgets)
     import_hbox3 = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(import_vbox), import_hbox3, FALSE, FALSE, 0);
 
-    import_label2 = gtk_label_new(_("They will have username based directories under the root directory:"));
+    import_label2 = gtk_label_new(_("Add users to closed private directories below FTP home:"));
     gtk_box_pack_start(GTK_BOX(import_hbox3), import_label2, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(import_label2), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment(GTK_MISC(import_label2), 0.02, 0.5);
     gtk_misc_set_padding(GTK_MISC(import_label2), 5, 7);
 
-    widgets->import_namebased_checkbutton = gtk_check_button_new_with_mnemonic("");
-    gtk_box_pack_start(GTK_BOX(import_hbox3), widgets->import_namebased_checkbutton, FALSE, FALSE, 0);
+    widgets->import_with_username_checkbutton = gtk_check_button_new_with_mnemonic("");
+    gtk_box_pack_start(GTK_BOX(import_hbox3), widgets->import_with_username_checkbutton, FALSE, FALSE, 0);
 
     import_hbox2 = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(import_vbox), import_hbox2, FALSE, FALSE, 0);
 
-    import_label3 = gtk_label_new(_("Add an upload directory under the root directory:"));
-    gtk_box_pack_start(GTK_BOX(import_hbox2), import_label3, FALSE, FALSE, 0);
-    gtk_label_set_justify(GTK_LABEL(import_label3), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment(GTK_MISC(import_label3), 0.02, 0.5);
-    gtk_misc_set_padding(GTK_MISC(import_label3), 5, 3);
-
-    widgets->import_upload_entry = gtk_entry_new();
-    gtk_box_pack_start(GTK_BOX(import_hbox2), widgets->import_upload_entry, TRUE, TRUE, 0);
-    gtk_tooltips_set_tip(tooltips, widgets->import_upload_entry, _("If you delete all text here and check the checkbutton then users will be able to upload directly in the root directory"), NULL);
-    gtk_entry_set_text(GTK_ENTRY(widgets->import_upload_entry), "upload");
-
-    widgets->import_upload_checkbutton = gtk_check_button_new_with_mnemonic("");
-    gtk_box_pack_start(GTK_BOX(import_hbox2), widgets->import_upload_checkbutton, FALSE, FALSE, 13);
-
     import_label4 = gtk_label_new("");
     gtk_box_pack_start(GTK_BOX(import_vbox), import_label4, FALSE, FALSE, 0);
     gtk_widget_set_size_request(import_label4, -1, 16);
@@ -201,11 +192,11 @@ void create_import_window(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(hbox3), label3, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(label3), GTK_JUSTIFY_LEFT);
 
-    g_signal_connect((gpointer)widgets->import_namebased_checkbutton, "toggled",
-                	    G_CALLBACK(import_namebased_checkbutton_toggled), widgets);
+//    g_signal_connect((gpointer)widgets->import_namebased_checkbutton, "toggled",
+//                	    G_CALLBACK(import_namebased_checkbutton_toggled), widgets);
 
-    g_signal_connect((gpointer)widgets->import_upload_checkbutton, "toggled",
-                	    G_CALLBACK(import_upload_checkbutton_toggled), widgets);
+//    g_signal_connect((gpointer)widgets->import_upload_checkbutton, "toggled",
+//                	    G_CALLBACK(import_upload_checkbutton_toggled), widgets);
 		    
     g_signal_connect((gpointer)import_button, "clicked",
                 	    G_CALLBACK(import_button_clicked), widgets);
@@ -218,9 +209,6 @@ void create_import_window(struct w *widgets)
 
 
 
-
-
-
     /* Populate the import treeview with users */
 
     if((fp=fopen(GP_PASSWD, "r"))==NULL)
@@ -250,10 +238,21 @@ void create_import_window(struct w *widgets)
 	    /* Dont insert root or the user the server runs as */
 	    if( !strcmp(new_buffer, "root") || !strcmp(new_buffer, SERVER_USER) )
 	      continue;
+
 		
 	    gtk_list_store_append(GTK_LIST_STORE(widgets->import_store), &iter);
+
 	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
 	    gtk_list_store_set(GTK_LIST_STORE(widgets->import_store), &iter, 0, utf8, -1);
+
+	    /* Get this users groupname */
+	    username = g_strdup_printf("%s", new_buffer);
+	    groupname = get_user_setting(username, "group");
+	    snprintf(new_buffer, 4000, "%s", groupname);
+	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
+	    gtk_list_store_set(GTK_LIST_STORE(widgets->import_store), &iter, 1, utf8, -1);
+	    g_free(username);
+	    g_free(groupname);
 	}
     }
     fclose(fp);
