@@ -36,6 +36,7 @@
 #include "create_server_settings.h"
 
 extern int use_tls;
+extern int use_ratio;
 
 
 
@@ -320,7 +321,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
 
-    /* FTP-TLS Begins here */
+    /* TLS Module settings begins here */
     if( use_tls )
     {
 	/* A hseparator */
@@ -459,9 +460,49 @@ void create_server_settings(struct w *widgets)
 
 	/* An apply button for the progress bar (make_button is in make_settings_progressbars.c) */
 	gen_cert_button = make_button(GTK_TABLE(widgets->srv_set_table), 0,1,a,b,200);
+	a++; b++;
+
 	g_signal_connect_swapped(G_OBJECT(gen_cert_button), "clicked",
 			 G_CALLBACK(generate_cert), widgets);	
     }
 
+
+
+
+    /* RATIO Module settings begins here */
+    if( use_ratio )
+    {
+	/* A hseparator */
+	make_3columns_hseparator(GTK_TABLE(widgets->srv_set_table), 0,1,a,b);
+	a++; b++;
+	
+	/* Ratio label */
+	make_3columns_label(GTK_TABLE(widgets->srv_set_table), _(" Ratios for uploads and downloads: "), 0,1,a,b);
+	a++; b++;
+
+	/* Use Ratios */
+	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use Ratios: "), 0,1,a,b,50);
+	combo_text = g_strdup_printf(_("On"));
+	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
+	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
+	combo_text = g_strdup_printf(_("Off"));
+	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
+	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
+	g_free(combo_text); g_free(utf8);
+	a++; b++; comb++;
+
+	/* Save Ratios */
+	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Save Ratios: "), 0,1,a,b,50);
+	combo_text = g_strdup_printf(_("On"));
+	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
+	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
+	combo_text = g_strdup_printf(_("Off"));
+	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
+	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
+	g_free(combo_text); g_free(utf8);
+	a++; b++; comb++;
+    }
+
+
     gtk_widget_show_all(widgets->main_window);
 }
