@@ -20,7 +20,6 @@
 
 
 
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>
@@ -33,7 +32,6 @@
 #include "add_user.h"
 #include "apply_user.h"
 
-
 #define EXPAND_USER_SECTION FALSE
 #define EXPAND_USER_SETTINGS_SECTION TRUE
 
@@ -45,10 +43,9 @@ void directory_cell_edited(GtkCellRendererText *cell,
 {
     /* Changes the edited directory cell text */
     GtkTreeIter iter;
-    GtkTreePath *path=NULL;
+    GtkTreePath *path = NULL;
 
     path = gtk_tree_path_new_from_string(path_string);
-
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, path);
 
     if( path!=NULL )
@@ -63,10 +60,10 @@ void toggle_button_1_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 1;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -86,10 +83,10 @@ void toggle_button_2_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 2;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -109,10 +106,10 @@ void toggle_button_3_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 3;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -131,10 +128,10 @@ void toggle_button_4_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 4;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -153,10 +150,10 @@ void toggle_button_5_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 5;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -176,10 +173,10 @@ void toggle_button_6_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 6;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -198,10 +195,10 @@ void toggle_button_7_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 7;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -220,10 +217,10 @@ void toggle_button_8_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 8;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -242,10 +239,10 @@ void toggle_button_9_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 9;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -264,10 +261,10 @@ void toggle_button_10_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 10;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -286,10 +283,10 @@ void toggle_button_11_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 11;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -308,10 +305,10 @@ void toggle_button_12_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 12;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -330,10 +327,10 @@ void toggle_button_13_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 13;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -352,10 +349,10 @@ void toggle_button_14_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 14;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -374,10 +371,10 @@ void toggle_button_15_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 15;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -396,10 +393,10 @@ void toggle_button_16_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 16;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -418,10 +415,10 @@ void toggle_button_17_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 17;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -440,10 +437,10 @@ void toggle_button_18_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
     GtkTreePath *treepath;
     GtkTreeIter iter;
     gboolean val;
-    treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     gint col_num = 18;
-    
+
+    treepath = gtk_tree_path_new_from_string(path);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->directory_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
 
@@ -460,25 +457,26 @@ void toggle_button_18_clicked(GtkCellRendererToggle *cell_renderer, gchar *path,
 
 void add_directory(struct w *widgets)
 {
-    /* Adds a directory with no permissions to the directory treeview */
+    /* Adds a directory with default permissions to the directory treeview */
+    int i = 0;
+    GtkTreeModel *model;
     GtkTreeIter iter;
     gchar *utf8 = NULL;
-    G_CONST_RETURN gchar *dir;
     gchar *dir_path;
 
-    dir =  gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[4]));
-
-    if( dir == NULL || strlen(dir) < 3 || ! strstr(dir, "/") )
-      dir_path = g_strdup_printf("/var/ftp/%s", _("Click_Here"));
-    else
-      dir_path = g_strdup_printf("%s/%s", dir, _("Click_Here"));
-    
+    dir_path = g_strdup_printf("/var/ftp/%s", _("Click_Here"));
     utf8 = g_locale_to_utf8(dir_path, strlen(dir_path), NULL, NULL, NULL);
-
     gtk_list_store_append(GTK_LIST_STORE(widgets->directory_store), &iter);
     gtk_list_store_set(widgets->directory_store, &iter, 0, utf8, -1);
-    
     g_free(dir_path);
+
+    /* Select a few default permissions for the directory */
+    model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->directory_treeview));
+    for(i=1; i<19; i++)
+    {
+	if( i==1 || i > 13 )
+	  gtk_list_store_set(widgets->directory_store, &iter, i, TRUE, -1);
+    }
     
     if( utf8!=NULL )
       g_free(utf8);
@@ -500,12 +498,10 @@ void del_directory(struct w *widgets)
 
     val = gtk_tree_selection_get_selected(GTK_TREE_SELECTION(selection), &model, &iter);
 
-
     path = gtk_tree_model_get_path(GTK_TREE_MODEL(model), &iter);
 
     has_row_above = gtk_tree_path_prev(path);
 
-
     /* A row is selected and its not the first one, remove it */
     if( val && has_row_above )
       gtk_list_store_remove(widgets->directory_store, &iter);
@@ -519,18 +515,15 @@ void create_user_tab(struct w *widgets)
     GtkCellRenderer *user_cell_renderer;
     GtkWidget *user_treeview_hbox, *user_settings_treeview_hbox;
     GtkWidget *user_scrolled_window, *directory_scrolled_window;
-
-    GtkCellRenderer *dir_cell_renderer;
     GtkCellRenderer *toggle_cell_renderer[19];
+    GtkCellRenderer *dir_cell_renderer;
     GtkTreeViewColumn *col[19];
-    int colnr=0;
-    int cellnr=0;
     GtkWidget *frame;
-    gchar *utf8=NULL;
+    int colnr = 0, cellnr = 0;
+    gchar *utf8 = NULL;
 
     GtkTooltips *tooltips;
     tooltips = gtk_tooltips_new();
-    
 
     /* Create the userlist treeview in a scrolled window */
     user_treeview_hbox = gtk_hbox_new(TRUE, 0);
@@ -581,7 +574,6 @@ void create_user_tab(struct w *widgets)
 
 
 
-
     /* Create the user settings scrolled window with a frame and a table */
     user_settings_treeview_hbox = gtk_hbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox2), user_settings_treeview_hbox, EXPAND_USER_SETTINGS_SECTION, TRUE, 0);
@@ -607,7 +599,6 @@ void create_user_tab(struct w *widgets)
     gtk_container_add(GTK_CONTAINER(frame), widgets->usr_set_table);
 
 
-
     /* Create the directory treeview in the user settings scrolled window */
     directory_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
     gtk_box_pack_start(GTK_BOX(widgets->user_settings_vbox), directory_scrolled_window, FALSE, FALSE, 0);
@@ -624,15 +615,13 @@ void create_user_tab(struct w *widgets)
     G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, 
     G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
     
-
+    /* Create the directory treeeview and add it to the scrolled window */
     widgets->directory_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_MODEL(widgets->directory_store));
 
     gtk_container_add(GTK_CONTAINER(directory_scrolled_window), widgets->directory_treeview);
     gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(widgets->directory_treeview), TRUE);
 
-
-
     /* Add the directory hbox */
     GtkWidget *add_dir_hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->user_settings_vbox), add_dir_hbox, FALSE, FALSE, 0);
@@ -913,7 +902,6 @@ void create_user_tab(struct w *widgets)
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->directory_treeview), GTK_TREE_VIEW_COLUMN(col[colnr]));
     colnr++; cellnr++;
 
-
     gtk_widget_show_all(widgets->main_window);
 
     if( utf8 != NULL )
