@@ -19,8 +19,6 @@
  */
 
 
-
-
 #include "../config.h"
 #include <gtk/gtk.h>
 #include "support.h"
@@ -29,6 +27,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <time.h>
+#include <ctype.h>
 #include "widgets.h"
 #include "chars_are_digits.h"
 #include "allocate.h"
@@ -48,6 +47,34 @@
 #endif
 
 
+/* Compare strings in lower case */
+int cmplowercase(char *buf, char *cmpstring)
+{
+    char *p, *newbuf;
+    int retval = 0;
+
+    if( buf==NULL )
+      return retval;
+
+    /* Ignore single newline chars */
+    if( strlen(buf) < 2 )
+      return retval;
+
+    newbuf = allocate(strlen(buf)+1);
+    /* Exists if it cant allocate */
+    sprintf(newbuf, "%s", buf);
+
+    for(p = newbuf; *p!='\0'; ++p)
+        *p = tolower(*p);
+
+    if( strstr(newbuf, cmpstring) )
+      retval = 1;
+
+    free(newbuf);
+
+    return retval;
+}
+
 
 int
 user_exists(G_CONST_RETURN gchar *username)
@@ -217,37 +244,37 @@ group_exists(G_CONST_RETURN gchar *groupname)
 	    free(check_buffer);
 	    fclose(fp);
       }
+
     return group_exists;
 }
 
 
-
 gchar *get_user_setting(gchar *user, gchar *what)
 {
-    /* Gets the users comment from passwd */
+    /* Gets the a specific users setting from passwd */
     FILE *fp;
     long conf_size;
     int x=0, y=0, found_user=0, found_val=0, count=0;
     char *tempname;
     char *check_buffer;
+    gchar *groupnumber;
     gchar *retval = NULL;
     gint val_pos = 0;
-                        
+
+    /* This is the group number */                        
     if( strstr(what, "group") )
       val_pos = 3;
-                          
+
     if( strstr(what, "comment") )
       val_pos = 4;
-                                                    
+
     if( strstr(what, "homedir") )
       val_pos = 5;
-                                                              
+
     if( strstr(what, "shell") )
       val_pos = 6;
-                                                                        
-                                                                    
+
     tempname = allocate(4096);
-                                                                            
     if((fp=fopen(GP_PASSWD,"r"))==NULL)
     {
         retval = g_strdup_printf(_("User setting not found"));
@@ -312,7 +339,16 @@ gchar *get_user_setting(gchar *user, gchar *what)
             /* Atleast one char in the value and max 350 */
             if( strlen(tempname) < 351 && ! strstr(tempname, ":") )
             {
-                retval = g_strdup_printf("%s", tempname);
+        	/* Convert the groupnumber to groupname */
+		if( strstr(what, "group") )
+		{
+		   groupnumber = g_strdup_printf("%s", tempname);
+		   retval = get_group_name(groupnumber);
+		   g_free(groupnumber);
+		}
+		else
+                  retval = g_strdup_printf("%s", tempname);
+
                 found_val = 1;
                 break;
             }
@@ -329,105 +365,99 @@ gchar *get_user_setting(gchar *user, gchar *what)
 }
 
 
-
-gchar *get_user_comment(gchar *user)
+gchar *get_group_name(gchar *groupnr)
 {
-    /* Gets the users comment from passwd */
+    /* Gets the system group name from the system group number */
     FILE *fp;
     long conf_size;
-    int x=0, y=0, found_user=0, found_comment=0, count=0;
-    char *tempname;
-    char *check_buffer;
-    gchar *comment=NULL;
+    int x=0, y=0, found_group_number=0;
+    int count=0,  found_group_name=0;
+    char *line, *temp;
+    gchar *retval = NULL;
+    gint val_pos = 0;
 
-    tempname = allocate(4096);    
+    /* position of the group number (name is always first) */
+    val_pos = 2;
 
-    if((fp=fopen(GP_PASSWD,"r"))==NULL)
+    temp = allocate(4096);    
+    if((fp=fopen(GP_GROUP,"r"))==NULL)
     {
-	comment = g_strdup_printf(_("No comment set"));
-	return comment;
+	retval = g_strdup_printf(_("Group file not found"));
+	free(temp);
+	return retval;
     }
-    else
-      {
-	    fseek(fp, 0, SEEK_END);
-	    conf_size = ftell(fp);
-	    rewind(fp);
+    fseek(fp, 0, SEEK_END);
+    conf_size = ftell(fp);
+    rewind(fp);
 
-	    check_buffer = allocate(conf_size);
+    line = allocate(conf_size+1);
 
-	    if( conf_size > 1 )
-	    while(fgets(check_buffer, conf_size, fp)!=NULL)
-	    {
-		for(x=0; check_buffer[x]; x++)
-		{
-		    if(check_buffer[x]==':')
-		    {
-			snprintf(tempname, 4000, "%s", check_buffer);
-			tempname[x]='\0';
-			if( ! strcmp(user, tempname) )
-			{
-			    found_user = 1;
-			    break;
-			}
-		    }
-		    if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-		      break;
-		}
-		if( found_user )
-		  break;
-	    }
-      }
-
-    fclose(fp);
-
-    /* If the user is found, get its comment */
-    if( found_user )
-    for(x=0; check_buffer[x]; x++)
+    if( conf_size > 1 )
+    while(fgets(line, conf_size, fp)!=NULL)
     {
-	if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-	  break;
+	count = 0;
 
-	if(check_buffer[x]==':')
+	for(x=0; line[x]!='\0'; x++)
 	{
-	    count++;
-	    /* The fourth colon is found, beginning of the comment */
-	    if( count == 4 )
+	    if( line[x]==':' )
+	      count++;
+		      
+	    if( count == val_pos )
+	      break;
+	}
+
+	snprintf(temp, 4000, "%s", &line[x+1]);
+
+	/* Snip an extra ":" at the end */			
+	for(y=strlen(temp)-1; temp[y]; y--)
+	{
+	    if( temp[y]==':' )
 	    {
-		snprintf(tempname, 4000, "%s", &check_buffer[x+1]);
+	        temp[y]='\0';
 		break;
 	    }
 	}
-    }
-
-    free(check_buffer);
-
-    /* Snip at comment end */
-    if( found_user )
-    for(y=0; tempname[y]; y++)
-    {
-	if(tempname[y]==':' && y > 0 )
+			
+	if( ! strcmp(groupnr, temp) )
 	{
-	    tempname[y]='\0';
+	    found_group_number = 1;
+	    break;
+	}
 
-	    /* Atleast one char in the comment and max < 350 */
-	    if( strlen(tempname) < 350 && ! strstr(tempname, ":") )
-	    {
-	        comment = g_strdup_printf("%s", tempname);
-	        found_comment = 1;
-	        break;
-	    }
+    }
+    fclose(fp);
+
+
+    count = 0;
+
+    /* Get the name of this group */
+    if( found_group_number )
+    for(y=strlen(line)-1; line[y]!='\0'; y--)
+    {
+	if( line[y]==':' && x < 4000 )
+	  count++;
+	
+	if( count == 3 )
+	{
+	    found_group_name = 1;
+	    snprintf(temp, y+1, "%s", line);
+	    break;
 	}
     }
-
-    free(tempname);
+    free(line);
 
     /* g_free'd after the return */    
-    if( found_comment )
-      return comment;
+    if( found_group_name )
+    {
+	retval = g_strdup_printf("%s", temp);
+	free(temp);
+        return retval;
+    }
 
-    comment = g_strdup_printf(_("No comment set"));
+    free(temp);
+    retval = g_strdup_printf(_("Group name not found"));
 
-    return comment;
+    return retval;
 }
 
 
@@ -729,40 +759,13 @@ fix_newlines_in_conf()
     return 1;
 }
 
-
-void
-fix_path(char *path)
-{
-    char *temp;
-    temp = allocate(4096);
-
-    /* Take away an unwanted star at the end */
-    if( path[strlen(path)-1]=='*' )
-	path[strlen(path)-1]='\0';
-    /* Take away an extra slash at the end */    
-    if( path[strlen(path)-1]=='/' )
-	path[strlen(path)-1]='\0';
-
-    /* Make sure we have a slash at the beginning of the path */    
-    if( path[0]!='/' )
-    {
-	snprintf(temp, 1024, "/%s", path);
-	snprintf(path, 1024, "%s", temp);
-    }        
-    if( temp!=NULL )
-      free(temp);    
-}
-
-
 void randomize_username(struct w *widgets)
 {
-    char *rnd_string;
-    char *homedir_username;
     int len;
+    char *rnd_string;
     gchar *info;
     gchar *utf8=NULL;
     G_CONST_RETURN gchar *default_username_length;
-    G_CONST_RETURN gchar *default_homedir;
 
     default_username_length = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_spinbutton[7]));
 
@@ -795,44 +798,7 @@ void randomize_username(struct w *widgets)
     if( utf8!=NULL )
       g_free(utf8);
 
-    /* Insert the randomized username after the path in the homedir entry */    
-    homedir_username = allocate(16384);
-
-    default_homedir = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[4]));
-    if( strlen((char *)default_homedir) > 8192 )
-    {
-	info = g_strdup_printf(_("Max home directory length is 8192 chars.\n"));
-	show_info(info);
-	g_free(info);
-	free(homedir_username);
-	free(rnd_string);
-	return;
-    }
-
-    snprintf(homedir_username, 8192, "%s", (char *)default_homedir);
-    
-    /* Strip some slashes and things we dont want */
-    if( homedir_username[strlen(homedir_username)-1]=='/' )
-        homedir_username[strlen(homedir_username)-1]='\0';
-
-    if( homedir_username[strlen(homedir_username)-1]=='/' )
-        homedir_username[strlen(homedir_username)-1]='\0';
-
-    if( homedir_username[strlen(homedir_username)-1]=='*' )
-        homedir_username[strlen(homedir_username)-1]='\0';
-
-    /* Add a slash to the end then the username */
-    strcat(homedir_username, "/");
-    strcat(homedir_username, rnd_string);
-
-    utf8 = g_locale_to_utf8(homedir_username, strlen(homedir_username), NULL, NULL, NULL);
-    gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), utf8);
-
-    if( utf8!=NULL )
-      g_free(utf8);
-    
     free(rnd_string);
-    free(homedir_username);
 }
 
 
