@@ -163,7 +163,7 @@ void generate_cert(struct w *widgets)
     while(gtk_events_pending())
 	  gtk_main_iteration();
     
-    /* Chmod_gprotls_conf_after_write */
+    /* Chmod gprotls.conf after write */
     snprintf(command, 1024, "chmod 600 %s/gprotls.conf", GP_APPCONFDIR);
     if( ! run_command(command) )
     {
@@ -390,8 +390,7 @@ void generate_cert(struct w *widgets)
 
 	info = g_strconcat(
 	"\n",
-	_("The certificate has been created successfully\n"),
-	_("and placed in the correct location.\n"),
+	_("The certificate has been created successfully and placed in the correct location.\n"),
 	_("It will be used by new FTP-TLS logins.\n"),
 	"\n", NULL);
 	show_info(info);
@@ -413,6 +412,5 @@ void generate_cert(struct w *widgets)
     free(command);
     free(pem_path);    
 
-
     reread_conf(widgets);
 }
