@@ -49,7 +49,19 @@
 
 int MAX_READ_POPEN = 16384;
 int activated = 0;
-int use_tls = 0;
+int use_tls   = 0;
+int use_ratio = 0;
+int use_quota = 0;
+
+/* Used globally when adding and importing users */
+long num_rows = 0;
+int row_pos   = 0;
+gchar *homedir=NULL;
+
+int info_window_exit_main = 0;
+
+/* Used to stop iteration when adding directories */
+int global_dir_error = 0;
 
 char global_server_address[1024]="";
 char global_server_port[1024]="";
@@ -57,14 +69,21 @@ char global_server_name[1024]="";
 char global_server_type[1024]="";
 char global_user_name[1024]="";
 
+/* Used to transform or remove deprecated options based on versions */
+char global_version[1024]="";
+
 
 
 int main(int argc, char *argv[])
 {
     FILE *fp;
-    int auto_security = 0;
+    int i=0, auto_security = 0;
     gchar *conf_path, *info, *cmd;
 
+    /* Missing pam file in FC-3,4,5,6 proftpd rpm so
+       Fedora users and me got tired of it */
+    gchar *broken_fedora; 
+
 #ifdef ENABLE_NLS
     bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
@@ -76,21 +95,34 @@ int main(int argc, char *argv[])
 
     wid* widgets = g_malloc(sizeof(wid));
 
+    /* Non root usage */
     if( ! getuid() == 0 )
     {
-	printf("You must be root to run: %s\n", PACKAGE);
-	info = g_strdup_printf("You must be root to run: %s\nThis window will close in 10 seconds.\n", PACKAGE);
-	show_info(info);
+	/* For setting a different exit method in the info window */
+	info_window_exit_main = 1;
+
+        info = g_strdup_printf("You must be root to run: %s\nThis window will close in 10 seconds.\n", PACKAGE);
+        show_info(info);
+        g_free(info);
+
+	/* Users can close the info window earlier then the timeout */
+	for(i=0; i<10; i++)
+	{
+    	    while(gtk_events_pending())
+                  gtk_main_iteration();
+
+	    /* Set when close info window is clicked */
+	    if( info_window_exit_main == 2 )
+	      break;
+
+    	    usleep(100000*10);
+    	}
 
-	while(gtk_events_pending())
-	     gtk_main_iteration();
-	sleep(10);
-	     
-	g_free(info);
 	g_free(widgets);
 	return 0;
     }
 
+
     
     /* Create the main window */
     create_main_window(widgets);
@@ -98,10 +130,20 @@ int main(int argc, char *argv[])
     /* Set ProFTPD Version */
     set_version(widgets);
 
+
     /* If proftpd has the mod_tls module we 
        create, show and use the TLS widgets */
     use_tls = using_tls();
 
+    /* If proftpd has the mod_ratio module we 
+       create, show and use the RATIO widgets */
+    use_ratio = using_ratio();
+
+    /* If proftpd has mod_quotatab and mod_quotatab_file
+       modules we create, show and use the TLS widgets */
+    use_quota = using_quota();
+
+
     /* Create the server tab */
     create_server_tab(widgets);
 
@@ -185,6 +227,41 @@ int main(int argc, char *argv[])
     }
 
 
+    /* Fix for broken Fedora-3,4,5,6 proftpd rpm */
+    if(  file_exists("/etc/fedora-release") 
+    &&   file_exists("/etc/pam.d")
+    && ! file_exists("/etc/pam.d/ftp") )
+    {
+	broken_fedora = g_strconcat("#%PAM-1.0\n",
+	"auth    required        pam_unix.so     nullok\n",
+	"account required        pam_unix.so\n",
+	"session required        pam_unix.so\n",
+	NULL);
+
+	if((fp=fopen("/etc/pam.d/ftp", "w+"))==NULL)
+        {
+	    info = g_strconcat("Fedora's version of proftpd doesnt add /etc/pam.d/ftp\n",
+	    "gproftpd has failed to add this file as well, this is a bug\n",
+	    NULL);
+	    show_info(info);
+	    g_free(info);
+        }  
+	else
+	{
+	    fputs(broken_fedora, fp);
+            fclose(fp);
+
+	    info = g_strconcat("Fedora's version of proftpd doesnt add /etc/pam.d/ftp\n",
+	    "Its been added now so that users can login\n",
+	    NULL);
+	    show_info(info);
+	    g_free(info);
+        }
+	
+	g_free(broken_fedora);
+    }
+
+
     /* Window close button (x) */   
     g_signal_connect(GTK_OBJECT(widgets->main_window), "destroy",
 	             GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
