@@ -30,6 +30,8 @@
 #include "allocate.h"
 #include "chars_are_digits.h"
 #include "populate_server_settings.h"
+#include "functions.h"
+#include "get_option_pos.h"
 
 
 extern char global_server_address[1024];
@@ -37,6 +39,8 @@ extern char global_server_port[1024];
 extern char global_server_type[1024];
 
 extern int use_tls;
+extern int use_ratio;
+extern int use_quota;
 
 
 
@@ -51,10 +55,6 @@ void populate_server_settings(struct w *widgets)
 
     if((fp=fopen(PROFTPD_CONF, "r"))==NULL)
     {
-	/* We just show this popup here too many windows looks bad */
-//	sprintf(info_buffer, "%s %s", _("List server: Cant open proftpd.conf here:\n"), PROFTPD_CONF);
-//        info_window = create_info_window ();
-//        gtk_widget_show (info_window);
         return;
     }
     fseek(fp, 0, SEEK_END);
@@ -66,10 +66,9 @@ void populate_server_settings(struct w *widgets)
     address_buffer = allocate(8192+15);
     translate = allocate(1024);
 
+
     if( strstr(global_server_type, "Virtualhost") )
-    {
        sprintf(address_buffer, "<VirtualHost %s>", global_server_address);
-    }
     else
        sprintf(address_buffer, global_server_address);
      
@@ -78,16 +77,13 @@ void populate_server_settings(struct w *widgets)
       sprintf(port_buffer, "Port %s", global_server_port);
 
       if( ! strstr((char *)global_server_type, "Virtualhost") )
-        found=1;
+        found = 1;
 
     if( conf_size > 1 )
     while(fgets(old_buffer, conf_size, fp)!=NULL)
     {                                 
 	if( strlen(old_buffer) > 8000 )
 	{
-//	    sprintf(info_buffer, _("A line with over 8000 chars is not valid in: %s\n"), PROFTPD_CONF);
-//    	    info_window=create_info_window();
-//    	    gtk_widget_show(info_window);
 	    fclose(fp);
 	    free(old_buffer);
 	    free(new_buffer);
@@ -97,15 +93,14 @@ void populate_server_settings(struct w *widgets)
 	    return;
 	}
 
-	
 	/* We have all the values for the selected default server */
-	if( strstr(old_buffer, "<Anonymous") && strstr((char *)global_server_type, "Default server") )
+	if( cmplowercase(old_buffer, "<anonymous")
+	&& strstr((char *)global_server_type, "Default server") )
 	  break;           
 
-
         /* We have a virtualhost with the same address as the selected server */
-        if( strstr("Virtualhost", (char *)global_server_type) && ! found
-	&&  strstr(old_buffer, address_buffer) )
+        if( strstr("Virtualhost", (char *)global_server_type)
+        && ! found && strstr(old_buffer, address_buffer) )
 	{
 	    /* Lets see if its the same port as the selected one */
 
@@ -117,41 +112,40 @@ void populate_server_settings(struct w *widgets)
 	    
 		/* This will expect the servers port on the second line ! 
 		 * else itll miss some vaules .. */
-		if( strstr(old_buffer, "Port") && strstr(old_buffer, port_buffer) )
+		if( cmplowercase(old_buffer, "port ")
+		&& strstr(old_buffer, port_buffer) )
 		{
-		    found=1;
+		    found = 1;
 		    break;
 		}
 		
-		if( strstr(old_buffer, "</Virtualhost>") )
+		if( cmplowercase(old_buffer, "</virtualhost>") )
 		  break;
 	    }    
 	}
 
-	
-
 	/* Continue until we find the selected server */
 	if( ! found )
 	  continue;
 
-
 	/* Read and insert the selected servers values in the servers tab */
 
 	/* If its the default server we stop listing the values when a vhost or anonymous is found */
 	if( ! strstr("Virtualhost", (char *)global_server_type)
-	&& ( strstr(old_buffer, "<Anonymous") || strstr(old_buffer, "<VirtualHost") ) )
+	&& ( cmplowercase(old_buffer, "<anonymous")
+	|| cmplowercase(old_buffer, "<virtualhost") ) )
 	   break;
 
 	/* In any case after listing the correct vhost and anon user we break */
-	if( strstr(old_buffer, "<Anonymous") && found )
+	if( cmplowercase(old_buffer, "<anonymous") && found )
 	   break;
 
 	/* In any case after listing the correct vhost we break */
-	if( strstr(old_buffer, "</VirtualHost") && found )
+	if( cmplowercase(old_buffer, "</virtualhost") && found )
 	   break;
 
 	/* The name of the server */	
-   	if( strstr(old_buffer, "ServerName") )
+   	if( cmplowercase(old_buffer, "servername") )
 	{   
 	    for(x=0; old_buffer[x]!='\0'; x++)
 	    {
@@ -174,7 +168,7 @@ void populate_server_settings(struct w *widgets)
 	    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[0]), utf8);
 	}
 
-	if( strstr(old_buffer, "ServerIdent") )
+	if( cmplowercase(old_buffer, "serverident") )
 	{
 	    for(x=0; old_buffer[x]!='\0'; x++)
 	    {
@@ -195,13 +189,13 @@ void populate_server_settings(struct w *widgets)
 	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
     	    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[1]), utf8);
 
-	    if( strstr(old_buffer, "on") )
+	    if( cmplowercase(old_buffer, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[0]), 1);
 	}
 
-	if( strstr(old_buffer, "MasqueradeAddress") )
+	if( cmplowercase(old_buffer, "masqueradeaddress") )
 	{
 	    new_buffer[0]='\0';
 	    sscanf(old_buffer, "%*s %s", new_buffer);
@@ -219,7 +213,7 @@ void populate_server_settings(struct w *widgets)
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[1]), 1);
 	}
 
-   	if( strstr(old_buffer, "ServerAdmin") )
+   	if( cmplowercase(old_buffer, "serveradmin") )
 	{   
 	    sprintf(new_buffer, &old_buffer[12]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -229,25 +223,25 @@ void populate_server_settings(struct w *widgets)
 	    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[3]), utf8);
 	}
 
-	if( strstr(old_buffer, "IdentLookups") )
+	if( cmplowercase(old_buffer, "identlookups") )
 	{
-	    if( strstr(old_buffer, "IdentLookups on") )
+	    if( cmplowercase(old_buffer, "identlookups on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[2]), 0);
 
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[2]), 1);
 	}
 
-        if( strstr(old_buffer, "UseReverseDNS") )
+        if( cmplowercase(old_buffer, "usereversedns") )
 	{
-	    if( strstr(old_buffer, "UseReverseDNS on") )
+	    if( cmplowercase(old_buffer, "usereversedns on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[3]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[3]), 1);
 	}
 
 	/* Off is local time */
-	if( strstr(old_buffer, "TimesGMT") )
+	if( cmplowercase(old_buffer, "timesgmt") )
 	{
 	    if( strstr(old_buffer, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[4]), 0);
@@ -256,7 +250,7 @@ void populate_server_settings(struct w *widgets)
 	}
 
 	/* Dont match passiveports */
-  	if( strstr(old_buffer, "Port") && old_buffer[4]==' ' && ! strstr(old_buffer, "PassivePorts") )
+  	if( cmplowercase(old_buffer, "port") && old_buffer[4]==' ' && ! strstr(old_buffer, "passiveports") )
 	{
 	    sscanf(old_buffer, "%*s %s", new_buffer);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -268,7 +262,7 @@ void populate_server_settings(struct w *widgets)
 	    }
 	}
 
-  	if( strstr(old_buffer, "PassivePorts")  )
+  	if( cmplowercase(old_buffer, "passiveports")  )
         {
 	    new_buffer[0]='\0';
 	    sscanf(old_buffer, "%*s %s", new_buffer);
@@ -294,7 +288,7 @@ void populate_server_settings(struct w *widgets)
 	}
 
 	/* Maximum simoultaneous connections */
-	if( strstr(old_buffer, "MaxInstances") )
+	if( cmplowercase(old_buffer, "maxinstances") )
 	{
 	    new_buffer[0]='\0';
 	    sscanf(old_buffer, "%*s %s", new_buffer);
@@ -309,7 +303,7 @@ void populate_server_settings(struct w *widgets)
 	}
 
 	/* Max login attempts */
-	if( strstr(old_buffer, "MaxLoginAttempts") )
+	if( cmplowercase(old_buffer, "maxloginattempts") )
 	{
 	    new_buffer[0]='\0';
 	    sscanf(old_buffer, "%*s %s", new_buffer);
@@ -323,7 +317,7 @@ void populate_server_settings(struct w *widgets)
 	}
 
 	/* Login timeout */
-	if( strstr(old_buffer, "TimeoutLogin") )
+	if( cmplowercase(old_buffer, "timeoutlogin") )
 	{
 	    new_buffer[0]='\0';
 	    sscanf(old_buffer, "%*s %s", new_buffer);
@@ -337,7 +331,7 @@ void populate_server_settings(struct w *widgets)
 	}
 	
 	/* Idle timeout */
-	if( strstr(old_buffer, "TimeoutNoTransfer") )
+	if( cmplowercase(old_buffer, "timeoutnotransfer") )
 	{
 	    new_buffer[0]='\0';
 	    sscanf(old_buffer, "%*s %s", new_buffer);
@@ -345,14 +339,13 @@ void populate_server_settings(struct w *widgets)
 	      new_buffer[strlen(new_buffer)-1]='\0';
 	    if( chars_are_digits(new_buffer) )
 	    {
-// IdleTimeout
         	val = atoi(new_buffer);
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[6]), val);
 	    }
 	}
 
 	/* Upload speed */
-	if( strstr(old_buffer, "TransferRate STOR") )
+	if( cmplowercase(old_buffer, "transferrate stor") )
 	{
 	    new_buffer[0]='\0';
 	    sscanf(old_buffer, "%*s %*s %s", new_buffer);
@@ -366,7 +359,7 @@ void populate_server_settings(struct w *widgets)
 	}
 
 	/* Dowonload speed */
-	if( strstr(old_buffer, "TransferRate RETR") )
+	if( cmplowercase(old_buffer, "transferrate retr") )
 	{
 	    new_buffer[0]='\0';
 	    sscanf(old_buffer, "%*s %*s %s", new_buffer);
@@ -380,7 +373,7 @@ void populate_server_settings(struct w *widgets)
 	}
 	
 	/* Transfer mode */	
-	if( strstr(old_buffer, "DefaultTransferMode") )
+	if( cmplowercase(old_buffer, "defaulttransfermode") )
 	{
 	    if( strstr(old_buffer, "binary") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[5]), 0);
@@ -389,7 +382,7 @@ void populate_server_settings(struct w *widgets)
 	}
 
 	/* FXP transfers */
-	if( strstr(old_buffer, "AllowForeignAddress") )
+	if( cmplowercase(old_buffer, "allowforeignaddress") )
 	{
 	    if( strstr(old_buffer, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[6]), 0);
@@ -398,7 +391,7 @@ void populate_server_settings(struct w *widgets)
 	}
 
 	/* Server user */
-	if( strstr(old_buffer, "User") && old_buffer[4]==' ' )
+	if( cmplowercase(old_buffer, "user") && old_buffer[4]==' ' )
 	{
 	    sscanf(old_buffer, "%*s %s", new_buffer);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -409,7 +402,7 @@ void populate_server_settings(struct w *widgets)
 	}
 
 	/* Server group */
-	if( strstr(old_buffer, "Group") && old_buffer[5]==' ' )
+	if( cmplowercase(old_buffer, "group") && old_buffer[5]==' ' )
 	{
 	    sscanf(old_buffer, "%*s %s", new_buffer);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -419,7 +412,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[10]), utf8);
 	}
 
-	if( strstr(old_buffer, "DirFakeUser") )
+	if( cmplowercase(old_buffer, "dirfakeuser") )
 	{
 	    /* Show the fake username */
 	    sscanf(old_buffer, "%*s %*s %s", new_buffer); 
@@ -434,7 +427,7 @@ void populate_server_settings(struct w *widgets)
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[8]), 1);
 	}
 
-	if( strstr(old_buffer, "DirFakeGroup") )
+	if( cmplowercase(old_buffer, "dirfakegroup") )
 	{
 	    /* Show the fake groupname */
 	    sscanf(old_buffer, "%*s %*s %s", new_buffer); 
@@ -449,7 +442,7 @@ void populate_server_settings(struct w *widgets)
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[9]), 1);
 	}
 
-	if( strstr(old_buffer, "AllowStoreRestart") )
+	if( cmplowercase(old_buffer, "allowstorerestart") )
 	{
 	    sscanf(old_buffer, "%*s %s", new_buffer);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -461,7 +454,7 @@ void populate_server_settings(struct w *widgets)
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[10]), 1);
 	}
 
-	if( strstr(old_buffer, "AllowRetrieveRestart") )
+	if( cmplowercase(old_buffer, "allowretrieverestart") )
 	{
 	    sscanf(old_buffer, "%*s %s", new_buffer);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -473,7 +466,7 @@ void populate_server_settings(struct w *widgets)
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[11]), 1);
 	}
 
-	if( strstr(old_buffer, "DeleteAbortedStores") )
+	if( cmplowercase(old_buffer, "deleteabortedstores") )
 	{
 	    if( strstr(old_buffer, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[12]), 0);
@@ -481,7 +474,7 @@ void populate_server_settings(struct w *widgets)
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[12]), 1);
 	}
 
-	if( strstr(old_buffer, "SystemLog") )
+	if( cmplowercase(old_buffer, "systemlog") )
 	{
 	    sprintf(new_buffer, &old_buffer[10]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -490,7 +483,7 @@ void populate_server_settings(struct w *widgets)
 	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[8]), utf8);
 	}
-	if( strstr(old_buffer, "gp_random_username_length") )
+	if( cmplowercase(old_buffer, "gp_random_username_length") )
 	{
 	    sscanf(old_buffer, "%*s %s", new_buffer);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -502,7 +495,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[7]), val);
 	    }
 	}
-	if( strstr(old_buffer, "gp_random_password_length") )
+	if( cmplowercase(old_buffer, "gp_random_password_length") )
 	{
 	    sscanf(old_buffer, "%*s %s", new_buffer);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -514,16 +507,16 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[8]), val);
 	    }
 	}
-	if( strstr(old_buffer, "gp_randomize_case") )
+	if( cmplowercase(old_buffer, "gp_randomize_case") )
 	{
-	    if( strstr(old_buffer, "upper") )
+	    if( cmplowercase(old_buffer, "upper") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[7]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[7]), 1);
 	}
 
 	/* This will be deprecated in a few years, the default conf adds gp_useradd_homedir_path (changed 2005-08-24) */
-	if( strstr(old_buffer, "gp_useradd_root_path") )
+	if( cmplowercase(old_buffer, "gp_useradd_root_path") )
 	{
 	    sprintf(new_buffer, &old_buffer[22]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -533,7 +526,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[4]), utf8);
 	}
 
-	if( strstr(old_buffer, "gp_useradd_homedir_path") )
+	if( cmplowercase(old_buffer, "gp_useradd_homedir_path") )
 	{
 	    sprintf(new_buffer, &old_buffer[25]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -543,7 +536,7 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[4]), utf8);
 	}
 
-	if( strstr(old_buffer, "gp_useradd_upload_path") )
+	if( cmplowercase(old_buffer, "gp_useradd_upload_path") )
 	{
 	    sprintf(new_buffer, &old_buffer[24]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -552,7 +545,7 @@ void populate_server_settings(struct w *widgets)
 	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[5]), utf8);
 	}
-	if( strstr(old_buffer, "gp_html_path") )
+	if( cmplowercase(old_buffer, "gp_html_path") )
 	{
 	    sprintf(new_buffer, &old_buffer[14]);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -565,36 +558,36 @@ void populate_server_settings(struct w *widgets)
 
 	if( use_tls )
 	{
-	    if( strstr(old_buffer, "TLSEngine") )
+	    if( cmplowercase(old_buffer, "tlsengine") )
 	    {
-		if( strstr(old_buffer, "on") )
+		if( cmplowercase(old_buffer, "on") )
 	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[13]), 0);
 		else
 	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[13]), 1);
 	    }
 
 	    /* On(Both), Off, Data, Control, */
-	    if( strstr(old_buffer, "TLSRequired") )
+	    if( cmplowercase(old_buffer, "tlsrequired") )
 	    {
-		if( strstr(old_buffer, "on") )
+		if( cmplowercase(old_buffer, "on") )
 	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[14]), 0);
-		if( strstr(old_buffer, "off") )
+		if( cmplowercase(old_buffer, "off") )
 	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[14]), 1);
-		if( strstr(old_buffer, "data") )
+		if( cmplowercase(old_buffer, "data") )
 	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[14]), 2);
-		if( strstr(old_buffer, "ctrl") )
+		if( cmplowercase(old_buffer, "ctrl") )
 	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[14]), 3);
 	    }
 
-	    if( strstr(old_buffer, "TLSVerifyClient") )
+	    if( cmplowercase(old_buffer, "tlsverifyclient") )
 	    {
-		if( strstr(old_buffer, "on") )
+		if( cmplowercase(old_buffer, "on") )
 	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[15]), 0);
 		else
 	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[15]), 1);
 	    }
 
-	    if( strstr(old_buffer, "TLSProtocol") )
+	    if( cmplowercase(old_buffer, "tlsprotocol") )
 	    {
 		sprintf(new_buffer, "%s", &old_buffer[12]);
 		if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -603,7 +596,7 @@ void populate_server_settings(struct w *widgets)
 		utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
         	gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[13]), utf8);
 	    }
-	    if( strstr(old_buffer, "TLSLog") )
+	    if( cmplowercase(old_buffer, "tlslog") )
 	    {
 		sprintf(new_buffer, &old_buffer[7]); 
 		if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -612,7 +605,7 @@ void populate_server_settings(struct w *widgets)
 		utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
         	gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[14]), utf8);
 	    }
-	    if( strstr(old_buffer, "TLSRSACertificateFile") )
+	    if( cmplowercase(old_buffer, "tlsrsacertificatefile") )
 	    {
 		sprintf(new_buffer, &old_buffer[22]); 
 		if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -621,7 +614,37 @@ void populate_server_settings(struct w *widgets)
 		utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
         	gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[15]), utf8);
 	    }
-	}  /* If use_tls (proftpd.conf values) */
+	}   /* If use_tls (proftpd.conf values) */
+
+
+	if( use_ratio )
+	{   /* Ratio on or off				   SaveRatios "ave" */
+	    if( cmplowercase(old_buffer, "ratios ") && ! cmplowercase(old_buffer, "ave") )
+	    {
+		if( cmplowercase(old_buffer, "on") )
+	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[16]), 0);
+		else
+	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[16]), 1);
+	    }
+
+	    /* Save Ratios on or off */
+	    if( cmplowercase(old_buffer, "saveratios ") )
+	    {
+		if( cmplowercase(old_buffer, "on") )
+	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[17]), 0);
+		else
+	          gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[17]), 1);
+	    }
+	}   /* If use_ratio end */
+
+
+	/* Fixme QUOTA */
+	if( use_quota )
+	{
+	
+		
+	}
+
     }
     fclose(fp);
     free(old_buffer);
@@ -631,6 +654,7 @@ void populate_server_settings(struct w *widgets)
 
 
     /* If we have the TLS module then list the values for it from gprotls.conf. */
+    /* These are generated by gproftpd so theres no need in using cmplowercase */
     if( use_tls )
     {
 	/* If we have a gprotls.conf then list the certificate values */
@@ -644,6 +668,7 @@ void populate_server_settings(struct w *widgets)
 	        fseek(fp, 0, SEEK_END);
 	        conf_size = ftell(fp);
 	        rewind(fp);
+
 	        old_buffer = allocate(conf_size);
 	        new_buffer = allocate(conf_size);
 
@@ -794,7 +819,7 @@ void populate_server_settings(struct w *widgets)
     free(translate);
 
     if( utf8!=NULL )
-    g_free(utf8);
+      g_free(utf8);
 
     gtk_widget_show_all(widgets->main_window);
 }
