@@ -31,6 +31,8 @@
 #include "widgets.h"
 #include "populate_servers.h"
 #include "show_info.h"
+#include "functions.h"
+#include "get_option_pos.h"
 
 extern char global_server_port[1024];
 extern char global_server_name[1024];
@@ -50,10 +52,8 @@ void populate_servers(struct w *widgets)
     int found=0;
     gchar *utf8=NULL;
 
-
     gtk_list_store_clear(widgets->server_store);
 
-
     /* Populate the serverlist */
     if((fp=fopen(PROFTPD_CONF, "r"))==NULL)
     {
@@ -79,13 +79,17 @@ void populate_servers(struct w *widgets)
     if( conf_size > 1 )
     while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
-	if( strstr(old_buffer, "<VirtualHost ") || strstr(old_buffer, "<Anonymous "))
+	if( cmplowercase(old_buffer, "<virtualhost ") || cmplowercase(old_buffer, "<snonymous "))
 	  break;
 	
 	new_buffer[0]='\0';
 
-	if( strstr(old_buffer, "Port ") && ! strstr(old_buffer, "PassivePorts ") && ! strstr(old_buffer, "standard") )
+	if( cmplowercase(old_buffer, "port ") && ! cmplowercase(old_buffer, "passiveports ")
+	&& ! cmplowercase(old_buffer, "standard") )
 	{
+
+// Fixme: use opt_pos = get_option_pos(old_buffer, 1);
+
 	    /* Insert the ipaddress or hostname */
 	    sprintf(new_buffer, "%s", &old_buffer[5]);
 	    new_buffer[strlen(new_buffer)-1]='\0';
