@@ -31,7 +31,6 @@
 #include "populate_user_settings.h"
 #include "chars_are_digits.h"
 #include "show_info.h"
-
 #include "populate_shell_combo.h"
 
 
@@ -41,11 +40,16 @@ extern char global_server_name[1024];
 extern char global_server_type[1024];
 extern char global_user_name[1024];
 
+extern int use_ratio;
+extern int use_quota;
 
+
+/* Move to header */
 void set_toggle_values(char *new_buffer, GtkTreeIter iter, struct w *widgets);
 
 
 
+
 /* Set toggle values for each directory in the directory treeview */
 void set_toggle_values(char *new_buffer, GtkTreeIter iter, struct w *widgets)
 {
@@ -138,6 +142,7 @@ void populate_user_settings(struct w *widgets)
     GtkTreeIter iter;
     char *new_buffer, *old_buffer, *user_buffer, *address_buffer;
     char *port_buffer, *spinval;
+    char *fr, *frc, *br, *brc; /* Used for ratio settings */
     long conf_size;
     int found = 0, homedir_vals_set = 0, i = 0, x = 0;
     int stats_checked = 1;
@@ -171,7 +176,7 @@ void populate_user_settings(struct w *widgets)
 	gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[3]), "");
 
 	/* Home directory */
-	gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), "/var/ftp");
+// Removed	gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), "/var/ftp");
 
 	/* Shell */
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->user_set_combo[0]), 0);
@@ -182,11 +187,27 @@ void populate_user_settings(struct w *widgets)
 	/* Show user in statistics */
         gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[2]), TRUE);
 
-	/* Max logins */
+	/* Max logins, set to 10 */
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[0]), 10);
 
 	/* Allow logins from */
 	gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[5]), "All");
+
+	/* Ratio defaults to disabled */
+	if( use_ratio )
+	{
+	    /* Byte ratio */
+	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[1]), 0);
+
+	    /* Byte ratio credit */
+	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[2]), 0);
+
+	    /* File ratio */
+	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[3]), 0);
+
+	    /* File ratio credit */
+	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[4]), 0);
+	}
     }
     g_free(info);
 
@@ -217,7 +238,7 @@ void populate_user_settings(struct w *widgets)
 
 
     /* Dont match a similar user */
-    sprintf(user_buffer, "User %s\n", global_user_name);
+    snprintf(user_buffer, 4000, "User %s\n", global_user_name);
 
 
     if( strstr((char *)global_server_type, "Virtualhost") )
@@ -293,18 +314,15 @@ void populate_user_settings(struct w *widgets)
 		gtk_list_store_set(GTK_LIST_STORE(widgets->directory_store), &iter, 0, utf8, -1);
 
 		/* Insert the root directory into the entry */
-		gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), utf8);
+// Removed		gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), utf8);
 
 		/* Username on the line after <Anonymous /var/ftp/dir> (cant be set before root dir) */
 		sscanf(old_buffer, "%*s %s", new_buffer);
 		utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
 		gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[0]), utf8);
 
-
 		found = 1;
 
-
-
 		/* Insert all the standard values like user, group etc */
 		while(fgets(old_buffer, conf_size, fp)!=NULL)
 		{
@@ -371,7 +389,53 @@ void populate_user_settings(struct w *widgets)
 			free(spinval);
 		    }
 
-		    
+
+		    /* Ratio Module */
+    		    if( use_ratio && strstr(old_buffer, "UserRatio ") && found )
+    		    {
+			/* Allocating all at once for clarity */
+			fr  = allocate(4096);
+			frc = allocate(4096);
+			br  = allocate(4096);
+			brc = allocate(4096);
+
+			/* Get the ratio numbers (file ratio, fileratio credit, byte ratio, byte ratio credit) */
+			sscanf(old_buffer, "%*s %*s %s %s %s %s", fr, frc, br, brc);
+			
+			/* Byte ratio spinbutton */
+			if( chars_are_digits(br) )
+			{
+			    spinvalue = atoi(br);
+			    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[1]), spinvalue);
+    			}
+			free(br);
+
+			/* Byte ratio credit spinbutton */
+			if( chars_are_digits(brc) )
+			{
+			    spinvalue = atoi(brc);
+			    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[2]), spinvalue);
+    			}
+			free(brc);
+
+			/* File ratio spinbutton */
+			if( chars_are_digits(fr) )
+			{
+			    spinvalue = atoi(fr);
+			    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[3]), spinvalue);
+    			}
+			free(fr);
+
+			/* File ratio credit spinbutton */
+			if( chars_are_digits(frc) )
+			{
+			    spinvalue = atoi(frc);
+			    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->user_set_spinbutton[4]), spinvalue);
+    			}
+			free(frc);
+		    }
+
+
 		    /* AllowOverwite setting in the directory treeview for the root directory */
 		    if( strstr(old_buffer, "AllowOverwrite on") )
 		      gtk_list_store_set(GTK_LIST_STORE(widgets->directory_store), &iter, 6, 1, -1);
