@@ -154,7 +154,7 @@ void populate_users(struct w *widgets)
     		    gtk_list_store_set(GTK_LIST_STORE(widgets->user_store), &iter, 0, utf8, -1);
 
 		    /* Insert user comment */
-		    user_comment = get_user_comment(new_buffer);
+		    user_comment = get_user_setting(new_buffer, "comment");
     		    utf8 = g_locale_to_utf8(user_comment, strlen(user_comment), NULL, NULL, NULL);
     		    gtk_list_store_set(GTK_LIST_STORE(widgets->user_store), &iter, 2, utf8, -1);
 		    if( user_comment!=NULL )
