@@ -19,8 +19,8 @@
  */
 
 
-#ifndef GDHCPD_reread_conf_H
-#	define GDHCPD_reread_conf_H
+#ifndef GPROFTPD_reread_conf_H
+#	define GPROFTPD_reread_conf_H
 
 extern struct w *widgets;
 
