@@ -74,7 +74,7 @@ void show_help()
   _("username, password and directory and then press the add button.\n\n"),
 
 
-  _("\n2 typical setups:\n\n"),
+  _("\nTypical setups:\n\n"),
 
   _("Users needs upload access to a http servers directory:\n\n"),
 
