@@ -22,6 +22,6 @@
 #ifndef HAVE_show_info_H
 #	define HAVE_show_info_H
 
-void show_info(char *content);
+void show_info(gchar *content);
 
 #endif
