@@ -19,32 +19,31 @@
  */
 
 
-
-
 #include "../config.h"
 #include <gtk/gtk.h>
 #include "gettext.h"
-#include "widgets.h"
-#include "functions.h"
-#include "standard_conf.h"
-#include "system_defines.h"
-#include "populate_gproftpd.h"
-#include "show_info.h"
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include "allocate.h"
+#include "widgets.h"
+#include "functions.h"
+#include "standard_conf.h"
+#include "populate_gproftpd.h"
+#include "show_info.h"
+#include "commented.h"
 
+/* Temporary for option deprecations */
+extern char global_version[1024];
 
 
 int conf_ok(gchar *file_path)
 {
     FILE *fp;
     long conf_size;
-    char *buffy;
+    char *line;
     int retval = 0;
-    int bad_conf = 0;
+    int good_conf = 0;
 
     if((fp=fopen(file_path, "r"))==NULL)
       return retval;
@@ -53,21 +52,52 @@ int conf_ok(gchar *file_path)
     conf_size = ftell(fp);
     rewind(fp);
 
-    buffy = allocate(conf_size+10);
+    line = allocate(conf_size+1);
 
     if( conf_size > 1 )      
-    while(fgets(buffy, conf_size, fp)!=NULL)
+    while(fgets(line, conf_size, fp)!=NULL)
     {
-	if( strstr(buffy, "Port 21 is the standard") )
-	  bad_conf = 1;
+	if( commented(line) )
+	  continue;
 
-	if( strstr(buffy, "port 21 is the standard") )
-	  bad_conf = 1;
+	/* Only check the standard server */
+	if( strstr(line, "<Anonymous") )
+	  break;
+	if( strstr(line, "<Virtual") )
+	  break;
+	if( strstr(line, "<IfModule") )
+	  break;
+
+	/* Very good for security so it must exist */
+	if( strstr(line, "<Limit LOGIN>") )
+	  good_conf++;
+
+	/* Refuse to use inetd */
+	if( strstr(line, "ServerType standalone") )
+	  good_conf++;
+
+	if( strstr(line, "TransferRate RETR") )
+	  good_conf++;
+
+	if( strstr(line, "TransferRate STOR") )
+	  good_conf++;
+
+	if( strstr(line, "TransferRate STOU") )
+	  good_conf++;
+
+	if( strstr(line, "TransferRate APPE") )
+	  good_conf++;
+
+	if( strstr(line, "PassivePorts") )
+	  good_conf++;
+
+	if( strstr(line, "DefaultTransferMode") )
+	  good_conf++;
     }
     fclose(fp);
-    free(buffy);
-    
-    if( ! bad_conf )
+    free(line);
+
+    if( good_conf == 7 )
       retval = 1;
 
     return retval;
@@ -81,6 +111,10 @@ void add_standard_conf(struct w *widgets)
     char *buffer;
     gchar *info;
 
+
+// FIXME: Backup any old configuration...
+
+
     /* Add the default configuration */
     if((fp=fopen(PROFTPD_CONF, "w+"))==NULL)
     {
@@ -89,9 +123,9 @@ void add_standard_conf(struct w *widgets)
 	return;
     }
 
-    buffer = allocate(100000);
+    buffer = allocate(102000);
 
-    /* These 3 are not in the global tab. FIXME: add inetd functions */
+    /* Note: inetd functions would limit the servers usability, def ENOADD */
     strcpy(buffer, "ServerType standalone\n");
     strcat(buffer, "DefaultServer on\n");
     strcat(buffer, "Umask 022\n");
@@ -117,7 +151,11 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, WELCOME_MESSAGE);
     strcat(buffer, "\n");
 
-    strcat(buffer, "DisplayFirstChdir .message\n");
+//  Fedora back ported/patched their version. WTH!...
+//    if( strstr(global_version,"1.2.") || strstr(global_version, "1.3.0") )
+//      strcat(buffer, "DisplayFirstChdir .message\n");
+//    else
+//      strcat(buffer, "DisplayChdir .message\n");
     
     strcat(buffer, "User ");
     strcat(buffer, SERVER_USER);
@@ -128,8 +166,7 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "\nDirFakeGroup off ");
     strcat(buffer, SERVER_GROUP);
     strcat(buffer, "\nDefaultTransferMode binary\n");
-
-    strcat(buffer, "AllowForeignAddress on\n");
+    strcat(buffer, "AllowForeignAddress off\n");
     strcat(buffer, "AllowRetrieveRestart on\n");
     strcat(buffer, "AllowStoreRestart on\n");
     strcat(buffer, "DeleteAbortedStores off\n");
@@ -138,53 +175,55 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "TransferRate STOU 40\n");
     strcat(buffer, "TransferRate APPE 40\n");
     strcat(buffer, "SystemLog ");
-
     strcat(buffer, GP_VARDIR);
     strcat(buffer, "/log/secure\n");
-
     strcat(buffer, "RequireValidShell off\n"); /* For using /dev/null as shell.. */
-
-
-    // FIXME, use in a settings window.
+    /* FIXME, use in a settings window. */
     strcat(buffer, "#gp_random_username_length 6\n");
     strcat(buffer, "#gp_random_password_length 6\n");
     strcat(buffer, "#gp_randomize_case lower\n");
     strcat(buffer, "#gp_useradd_homedir_path /var/ftp\n");
-    strcat(buffer, "#gp_useradd_upload_path /upload\n");
-
+// Deprecated    strcat(buffer, "#gp_useradd_upload_path /upload\n");
     strcat(buffer, "#gp_html_path ");
     strcat(buffer, HTML_STATISTICS);
     strcat(buffer, "\n");
-
     strcat(buffer, "#gp_welcome_name ");
     strcat(buffer, WELCOME_MESSAGE);
     strcat(buffer, "\n");
 
-
-
-    /* By default TLS is off */ 
+    /* TLS Module settings, off by default */ 
     strcat(buffer, "<IfModule mod_tls.c>\n");
     strcat(buffer, "TLSEngine off\n");
     strcat(buffer, "TLSRequired off\n");
     strcat(buffer, "TLSVerifyClient off\n");
     strcat(buffer, "TLSProtocol TLSv1\n");
     strcat(buffer, "TLSLog ");
-
     strcat(buffer, GP_VARDIR);
     strcat(buffer, "/log/proftpd_tls.log\n");
-
     strcat(buffer, "TLSRSACertificateFile ");
     strcat(buffer, GP_APPCONFDIR); 
     strcat(buffer, "/gproftpd.pem\n");
-
 //    strcat(buffer, "#CA the server trusts\n");
 //    strcat(buffer, "#TLSCACertificateFile /etc/gproftpd/certs/root.cert.pem\n");
     strcat(buffer, "</IfModule>\n");
 
+    /* RATIO Module settings, off by default */ 
+    strcat(buffer, "<IfModule mod_ratio.c>\n");
+    strcat(buffer, "Ratios off\n");
+    strcat(buffer, "SaveRatios off\n");
+    strcat(buffer, "RatioFile \"/restricted/proftpd_ratios\"\n");
+    strcat(buffer, "RatioTempFile \"/restricted/proftpd_ratios_temp\"\n");
+    strcat(buffer, "CwdRatioMsg \"Please upload first!\"\n");
+    strcat(buffer, "FileRatioErrMsg \"FileRatio limit exceeded, upload something first...\"\n");
+    strcat(buffer, "ByteRatioErrMsg \"ByteRatio limit exceeded, upload something first...\"\n");
+    strcat(buffer, "LeechRatioMsg \"Your ratio is unlimited.\"\n");
+    strcat(buffer, "</IfModule>\n");
+
+    /* Login restriction */
     strcat(buffer, "<Limit LOGIN>\n");
     strcat(buffer, "  DenyALL\n");
     strcat(buffer, "</Limit>\n\n");
-	    
+
     fputs(buffer, fp);
     fclose(fp);
     free(buffer);
@@ -198,7 +237,9 @@ void add_standard_conf(struct w *widgets)
 
 void dont_add_standard_conf(struct w *widgets)
 {
-    gtk_widget_destroy(widgets->default_conf_question_window);
+    if( GTK_IS_WINDOW(widgets->default_conf_question_window) )
+      gtk_widget_destroy(widgets->default_conf_question_window);
+
     populate_gproftpd(widgets);
 }
 
